#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CropsGrowthInfo import CropsGrowthInfo
from alipay.aop.api.domain.AgWeatherMonthlyStats import AgWeatherMonthlyStats
from alipay.aop.api.domain.CropsSoilMoistureInfo import CropsSoilMoistureInfo
from alipay.aop.api.domain.AgWeatherDisasterHistory import AgWeatherDisasterHistory
from alipay.aop.api.domain.AgWeatherDisasterInfo import AgWeatherDisasterInfo
from alipay.aop.api.domain.AgWeatherForecastInfo import AgWeatherForecastInfo
from alipay.aop.api.domain.AgWeatherWeeklyStats import AgWeatherWeeklyStats


class AnttechBlockchainDefinDataserviceCropdetailQueryResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainDefinDataserviceCropdetailQueryResponse, self).__init__()
        self._growth_infos = None
        self._month_weather_infos = None
        self._soil_moisture_infos = None
        self._weather_disaster_history = None
        self._weather_disaster_infos = None
        self._weather_forecast_infos = None
        self._week_weather_infos = None

    @property
    def growth_infos(self):
        return self._growth_infos

    @growth_infos.setter
    def growth_infos(self, value):
        if isinstance(value, list):
            self._growth_infos = list()
            for i in value:
                if isinstance(i, CropsGrowthInfo):
                    self._growth_infos.append(i)
                else:
                    self._growth_infos.append(CropsGrowthInfo.from_alipay_dict(i))
    @property
    def month_weather_infos(self):
        return self._month_weather_infos

    @month_weather_infos.setter
    def month_weather_infos(self, value):
        if isinstance(value, list):
            self._month_weather_infos = list()
            for i in value:
                if isinstance(i, AgWeatherMonthlyStats):
                    self._month_weather_infos.append(i)
                else:
                    self._month_weather_infos.append(AgWeatherMonthlyStats.from_alipay_dict(i))
    @property
    def soil_moisture_infos(self):
        return self._soil_moisture_infos

    @soil_moisture_infos.setter
    def soil_moisture_infos(self, value):
        if isinstance(value, list):
            self._soil_moisture_infos = list()
            for i in value:
                if isinstance(i, CropsSoilMoistureInfo):
                    self._soil_moisture_infos.append(i)
                else:
                    self._soil_moisture_infos.append(CropsSoilMoistureInfo.from_alipay_dict(i))
    @property
    def weather_disaster_history(self):
        return self._weather_disaster_history

    @weather_disaster_history.setter
    def weather_disaster_history(self, value):
        if isinstance(value, AgWeatherDisasterHistory):
            self._weather_disaster_history = value
        else:
            self._weather_disaster_history = AgWeatherDisasterHistory.from_alipay_dict(value)
    @property
    def weather_disaster_infos(self):
        return self._weather_disaster_infos

    @weather_disaster_infos.setter
    def weather_disaster_infos(self, value):
        if isinstance(value, list):
            self._weather_disaster_infos = list()
            for i in value:
                if isinstance(i, AgWeatherDisasterInfo):
                    self._weather_disaster_infos.append(i)
                else:
                    self._weather_disaster_infos.append(AgWeatherDisasterInfo.from_alipay_dict(i))
    @property
    def weather_forecast_infos(self):
        return self._weather_forecast_infos

    @weather_forecast_infos.setter
    def weather_forecast_infos(self, value):
        if isinstance(value, list):
            self._weather_forecast_infos = list()
            for i in value:
                if isinstance(i, AgWeatherForecastInfo):
                    self._weather_forecast_infos.append(i)
                else:
                    self._weather_forecast_infos.append(AgWeatherForecastInfo.from_alipay_dict(i))
    @property
    def week_weather_infos(self):
        return self._week_weather_infos

    @week_weather_infos.setter
    def week_weather_infos(self, value):
        if isinstance(value, list):
            self._week_weather_infos = list()
            for i in value:
                if isinstance(i, AgWeatherWeeklyStats):
                    self._week_weather_infos.append(i)
                else:
                    self._week_weather_infos.append(AgWeatherWeeklyStats.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainDefinDataserviceCropdetailQueryResponse, self).parse_response_content(response_content)
        if 'growth_infos' in response:
            self.growth_infos = response['growth_infos']
        if 'month_weather_infos' in response:
            self.month_weather_infos = response['month_weather_infos']
        if 'soil_moisture_infos' in response:
            self.soil_moisture_infos = response['soil_moisture_infos']
        if 'weather_disaster_history' in response:
            self.weather_disaster_history = response['weather_disaster_history']
        if 'weather_disaster_infos' in response:
            self.weather_disaster_infos = response['weather_disaster_infos']
        if 'weather_forecast_infos' in response:
            self.weather_forecast_infos = response['weather_forecast_infos']
        if 'week_weather_infos' in response:
            self.week_weather_infos = response['week_weather_infos']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPcreditHuabeiSceneprodBenefitSendModel(object):

    def __init__(self):
        self._benefit_channel = None
        self._benefit_id = None
        self._benefit_type = None
        self._biz_date = None
        self._biz_scene = None
        self._instance_id = None
        self._memo = None
        self._open_id = None
        self._out_request_no = None
        self._partner_id = None
        self._request_from = None
        self._security_content = None
        self._user_id = None

    @property
    def benefit_channel(self):
        return self._benefit_channel

    @benefit_channel.setter
    def benefit_channel(self, value):
        self._benefit_channel = value
    @property
    def benefit_id(self):
        return self._benefit_id

    @benefit_id.setter
    def benefit_id(self, value):
        self._benefit_id = value
    @property
    def benefit_type(self):
        return self._benefit_type

    @benefit_type.setter
    def benefit_type(self, value):
        self._benefit_type = value
    @property
    def biz_date(self):
        return self._biz_date

    @biz_date.setter
    def biz_date(self, value):
        self._biz_date = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def instance_id(self):
        return self._instance_id

    @instance_id.setter
    def instance_id(self, value):
        self._instance_id = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def request_from(self):
        return self._request_from

    @request_from.setter
    def request_from(self, value):
        self._request_from = value
    @property
    def security_content(self):
        return self._security_content

    @security_content.setter
    def security_content(self, value):
        self._security_content = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.benefit_channel:
            if hasattr(self.benefit_channel, 'to_alipay_dict'):
                params['benefit_channel'] = self.benefit_channel.to_alipay_dict()
            else:
                params['benefit_channel'] = self.benefit_channel
        if self.benefit_id:
            if hasattr(self.benefit_id, 'to_alipay_dict'):
                params['benefit_id'] = self.benefit_id.to_alipay_dict()
            else:
                params['benefit_id'] = self.benefit_id
        if self.benefit_type:
            if hasattr(self.benefit_type, 'to_alipay_dict'):
                params['benefit_type'] = self.benefit_type.to_alipay_dict()
            else:
                params['benefit_type'] = self.benefit_type
        if self.biz_date:
            if hasattr(self.biz_date, 'to_alipay_dict'):
                params['biz_date'] = self.biz_date.to_alipay_dict()
            else:
                params['biz_date'] = self.biz_date
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.instance_id:
            if hasattr(self.instance_id, 'to_alipay_dict'):
                params['instance_id'] = self.instance_id.to_alipay_dict()
            else:
                params['instance_id'] = self.instance_id
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.request_from:
            if hasattr(self.request_from, 'to_alipay_dict'):
                params['request_from'] = self.request_from.to_alipay_dict()
            else:
                params['request_from'] = self.request_from
        if self.security_content:
            if hasattr(self.security_content, 'to_alipay_dict'):
                params['security_content'] = self.security_content.to_alipay_dict()
            else:
                params['security_content'] = self.security_content
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditHuabeiSceneprodBenefitSendModel()
        if 'benefit_channel' in d:
            o.benefit_channel = d['benefit_channel']
        if 'benefit_id' in d:
            o.benefit_id = d['benefit_id']
        if 'benefit_type' in d:
            o.benefit_type = d['benefit_type']
        if 'biz_date' in d:
            o.biz_date = d['biz_date']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'instance_id' in d:
            o.instance_id = d['instance_id']
        if 'memo' in d:
            o.memo = d['memo']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'request_from' in d:
            o.request_from = d['request_from']
        if 'security_content' in d:
            o.security_content = d['security_content']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TransferAmount import TransferAmount


class TransferPaymentItem(object):

    def __init__(self):
        self._channel_accept_time = None
        self._channel_remit_time = None
        self._mandatory_payment = None
        self._partial_allowed = None
        self._payment_completed = None
        self._payment_item_amount = None
        self._payment_item_id = None
        self._payment_item_name = None
        self._payment_item_type = None
        self._payment_local_name = None

    @property
    def channel_accept_time(self):
        return self._channel_accept_time

    @channel_accept_time.setter
    def channel_accept_time(self, value):
        self._channel_accept_time = value
    @property
    def channel_remit_time(self):
        return self._channel_remit_time

    @channel_remit_time.setter
    def channel_remit_time(self, value):
        self._channel_remit_time = value
    @property
    def mandatory_payment(self):
        return self._mandatory_payment

    @mandatory_payment.setter
    def mandatory_payment(self, value):
        self._mandatory_payment = value
    @property
    def partial_allowed(self):
        return self._partial_allowed

    @partial_allowed.setter
    def partial_allowed(self, value):
        self._partial_allowed = value
    @property
    def payment_completed(self):
        return self._payment_completed

    @payment_completed.setter
    def payment_completed(self, value):
        self._payment_completed = value
    @property
    def payment_item_amount(self):
        return self._payment_item_amount

    @payment_item_amount.setter
    def payment_item_amount(self, value):
        if isinstance(value, TransferAmount):
            self._payment_item_amount = value
        else:
            self._payment_item_amount = TransferAmount.from_alipay_dict(value)
    @property
    def payment_item_id(self):
        return self._payment_item_id

    @payment_item_id.setter
    def payment_item_id(self, value):
        self._payment_item_id = value
    @property
    def payment_item_name(self):
        return self._payment_item_name

    @payment_item_name.setter
    def payment_item_name(self, value):
        self._payment_item_name = value
    @property
    def payment_item_type(self):
        return self._payment_item_type

    @payment_item_type.setter
    def payment_item_type(self, value):
        self._payment_item_type = value
    @property
    def payment_local_name(self):
        return self._payment_local_name

    @payment_local_name.setter
    def payment_local_name(self, value):
        self._payment_local_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.channel_accept_time:
            if hasattr(self.channel_accept_time, 'to_alipay_dict'):
                params['channel_accept_time'] = self.channel_accept_time.to_alipay_dict()
            else:
                params['channel_accept_time'] = self.channel_accept_time
        if self.channel_remit_time:
            if hasattr(self.channel_remit_time, 'to_alipay_dict'):
                params['channel_remit_time'] = self.channel_remit_time.to_alipay_dict()
            else:
                params['channel_remit_time'] = self.channel_remit_time
        if self.mandatory_payment:
            if hasattr(self.mandatory_payment, 'to_alipay_dict'):
                params['mandatory_payment'] = self.mandatory_payment.to_alipay_dict()
            else:
                params['mandatory_payment'] = self.mandatory_payment
        if self.partial_allowed:
            if hasattr(self.partial_allowed, 'to_alipay_dict'):
                params['partial_allowed'] = self.partial_allowed.to_alipay_dict()
            else:
                params['partial_allowed'] = self.partial_allowed
        if self.payment_completed:
            if hasattr(self.payment_completed, 'to_alipay_dict'):
                params['payment_completed'] = self.payment_completed.to_alipay_dict()
            else:
                params['payment_completed'] = self.payment_completed
        if self.payment_item_amount:
            if hasattr(self.payment_item_amount, 'to_alipay_dict'):
                params['payment_item_amount'] = self.payment_item_amount.to_alipay_dict()
            else:
                params['payment_item_amount'] = self.payment_item_amount
        if self.payment_item_id:
            if hasattr(self.payment_item_id, 'to_alipay_dict'):
                params['payment_item_id'] = self.payment_item_id.to_alipay_dict()
            else:
                params['payment_item_id'] = self.payment_item_id
        if self.payment_item_name:
            if hasattr(self.payment_item_name, 'to_alipay_dict'):
                params['payment_item_name'] = self.payment_item_name.to_alipay_dict()
            else:
                params['payment_item_name'] = self.payment_item_name
        if self.payment_item_type:
            if hasattr(self.payment_item_type, 'to_alipay_dict'):
                params['payment_item_type'] = self.payment_item_type.to_alipay_dict()
            else:
                params['payment_item_type'] = self.payment_item_type
        if self.payment_local_name:
            if hasattr(self.payment_local_name, 'to_alipay_dict'):
                params['payment_local_name'] = self.payment_local_name.to_alipay_dict()
            else:
                params['payment_local_name'] = self.payment_local_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TransferPaymentItem()
        if 'channel_accept_time' in d:
            o.channel_accept_time = d['channel_accept_time']
        if 'channel_remit_time' in d:
            o.channel_remit_time = d['channel_remit_time']
        if 'mandatory_payment' in d:
            o.mandatory_payment = d['mandatory_payment']
        if 'partial_allowed' in d:
            o.partial_allowed = d['partial_allowed']
        if 'payment_completed' in d:
            o.payment_completed = d['payment_completed']
        if 'payment_item_amount' in d:
            o.payment_item_amount = d['payment_item_amount']
        if 'payment_item_id' in d:
            o.payment_item_id = d['payment_item_id']
        if 'payment_item_name' in d:
            o.payment_item_name = d['payment_item_name']
        if 'payment_item_type' in d:
            o.payment_item_type = d['payment_item_type']
        if 'payment_local_name' in d:
            o.payment_local_name = d['payment_local_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFinancialnetAuthSpaccountConsultResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFinancialnetAuthSpaccountConsultResponse, self).__init__()
        self._display_opened_account_logon_id = None
        self._error_code = None
        self._error_message = None
        self._is_success = None
        self._opened_account = None
        self._opened_account_user_id = None
        self._opened_account_user_open_id = None

    @property
    def display_opened_account_logon_id(self):
        return self._display_opened_account_logon_id

    @display_opened_account_logon_id.setter
    def display_opened_account_logon_id(self, value):
        self._display_opened_account_logon_id = value
    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_message(self):
        return self._error_message

    @error_message.setter
    def error_message(self, value):
        self._error_message = value
    @property
    def is_success(self):
        return self._is_success

    @is_success.setter
    def is_success(self, value):
        self._is_success = value
    @property
    def opened_account(self):
        return self._opened_account

    @opened_account.setter
    def opened_account(self, value):
        self._opened_account = value
    @property
    def opened_account_user_id(self):
        return self._opened_account_user_id

    @opened_account_user_id.setter
    def opened_account_user_id(self, value):
        self._opened_account_user_id = value
    @property
    def opened_account_user_open_id(self):
        return self._opened_account_user_open_id

    @opened_account_user_open_id.setter
    def opened_account_user_open_id(self, value):
        self._opened_account_user_open_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayFinancialnetAuthSpaccountConsultResponse, self).parse_response_content(response_content)
        if 'display_opened_account_logon_id' in response:
            self.display_opened_account_logon_id = response['display_opened_account_logon_id']
        if 'error_code' in response:
            self.error_code = response['error_code']
        if 'error_message' in response:
            self.error_message = response['error_message']
        if 'is_success' in response:
            self.is_success = response['is_success']
        if 'opened_account' in response:
            self.opened_account = response['opened_account']
        if 'opened_account_user_id' in response:
            self.opened_account_user_id = response['opened_account_user_id']
        if 'opened_account_user_open_id' in response:
            self.opened_account_user_open_id = response['opened_account_user_open_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class IotVspOrgUserDeleteNotifyUserInfoRequest(object):

    def __init__(self):
        self._msg = None
        self._state = None
        self._vid = None

    @property
    def msg(self):
        return self._msg

    @msg.setter
    def msg(self, value):
        self._msg = value
    @property
    def state(self):
        return self._state

    @state.setter
    def state(self, value):
        self._state = value
    @property
    def vid(self):
        return self._vid

    @vid.setter
    def vid(self, value):
        self._vid = value


    def to_alipay_dict(self):
        params = dict()
        if self.msg:
            if hasattr(self.msg, 'to_alipay_dict'):
                params['msg'] = self.msg.to_alipay_dict()
            else:
                params['msg'] = self.msg
        if self.state:
            if hasattr(self.state, 'to_alipay_dict'):
                params['state'] = self.state.to_alipay_dict()
            else:
                params['state'] = self.state
        if self.vid:
            if hasattr(self.vid, 'to_alipay_dict'):
                params['vid'] = self.vid.to_alipay_dict()
            else:
                params['vid'] = self.vid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IotVspOrgUserDeleteNotifyUserInfoRequest()
        if 'msg' in d:
            o.msg = d['msg']
        if 'state' in d:
            o.state = d['state']
        if 'vid' in d:
            o.vid = d['vid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.EndTimeInfo import EndTimeInfo


class TimeRangeInfo(object):

    def __init__(self):
        self._begin_time = None
        self._end_time_info = None

    @property
    def begin_time(self):
        return self._begin_time

    @begin_time.setter
    def begin_time(self, value):
        self._begin_time = value
    @property
    def end_time_info(self):
        return self._end_time_info

    @end_time_info.setter
    def end_time_info(self, value):
        if isinstance(value, EndTimeInfo):
            self._end_time_info = value
        else:
            self._end_time_info = EndTimeInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.begin_time:
            if hasattr(self.begin_time, 'to_alipay_dict'):
                params['begin_time'] = self.begin_time.to_alipay_dict()
            else:
                params['begin_time'] = self.begin_time
        if self.end_time_info:
            if hasattr(self.end_time_info, 'to_alipay_dict'):
                params['end_time_info'] = self.end_time_info.to_alipay_dict()
            else:
                params['end_time_info'] = self.end_time_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TimeRangeInfo()
        if 'begin_time' in d:
            o.begin_time = d['begin_time']
        if 'end_time_info' in d:
            o.end_time_info = d['end_time_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InteligentPublishChannel(object):

    def __init__(self):
        self._config = None
        self._ext_info = None
        self._name = None
        self._type = None

    @property
    def config(self):
        return self._config

    @config.setter
    def config(self, value):
        self._config = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.config:
            if hasattr(self.config, 'to_alipay_dict'):
                params['config'] = self.config.to_alipay_dict()
            else:
                params['config'] = self.config
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InteligentPublishChannel()
        if 'config' in d:
            o.config = d['config']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'name' in d:
            o.name = d['name']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.UserBusiness import UserBusiness


class AlipayDataIotdataUserBusinessQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataIotdataUserBusinessQueryResponse, self).__init__()
        self._data = None

    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        if isinstance(value, list):
            self._data = list()
            for i in value:
                if isinstance(i, UserBusiness):
                    self._data.append(i)
                else:
                    self._data.append(UserBusiness.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayDataIotdataUserBusinessQueryResponse, self).parse_response_content(response_content)
        if 'data' in response:
            self.data = response['data']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcoMycarOrderStatusQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoMycarOrderStatusQueryResponse, self).__init__()
        self._alipay_order_id = None
        self._car_order_id = None
        self._equipment_order_id = None
        self._pay_money = None
        self._pay_status = None
        self._pay_time = None
        self._pay_type = None
        self._status = None

    @property
    def alipay_order_id(self):
        return self._alipay_order_id

    @alipay_order_id.setter
    def alipay_order_id(self, value):
        self._alipay_order_id = value
    @property
    def car_order_id(self):
        return self._car_order_id

    @car_order_id.setter
    def car_order_id(self, value):
        self._car_order_id = value
    @property
    def equipment_order_id(self):
        return self._equipment_order_id

    @equipment_order_id.setter
    def equipment_order_id(self, value):
        self._equipment_order_id = value
    @property
    def pay_money(self):
        return self._pay_money

    @pay_money.setter
    def pay_money(self, value):
        self._pay_money = value
    @property
    def pay_status(self):
        return self._pay_status

    @pay_status.setter
    def pay_status(self, value):
        self._pay_status = value
    @property
    def pay_time(self):
        return self._pay_time

    @pay_time.setter
    def pay_time(self, value):
        self._pay_time = value
    @property
    def pay_type(self):
        return self._pay_type

    @pay_type.setter
    def pay_type(self, value):
        self._pay_type = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoMycarOrderStatusQueryResponse, self).parse_response_content(response_content)
        if 'alipay_order_id' in response:
            self.alipay_order_id = response['alipay_order_id']
        if 'car_order_id' in response:
            self.car_order_id = response['car_order_id']
        if 'equipment_order_id' in response:
            self.equipment_order_id = response['equipment_order_id']
        if 'pay_money' in response:
            self.pay_money = response['pay_money']
        if 'pay_status' in response:
            self.pay_status = response['pay_status']
        if 'pay_time' in response:
            self.pay_time = response['pay_time']
        if 'pay_type' in response:
            self.pay_type = response['pay_type']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BeneficialEntity import BeneficialEntity
from alipay.aop.api.domain.FinAttachment import FinAttachment
from alipay.aop.api.domain.BeneficialEntity import BeneficialEntity
from alipay.aop.api.domain.BankAccount import BankAccount
from alipay.aop.api.domain.TradeInformation import TradeInformation


class AnttechBlockchainFinanceTruspleLoanapplySubmitModel(object):

    def __init__(self):
        self._actual_controllers = None
        self._attachments = None
        self._beneficiaries = None
        self._borrower_type = None
        self._external_credit_grant_id = None
        self._external_loan_id = None
        self._external_loan_request_id = None
        self._external_product_code = None
        self._external_user_id = None
        self._inst_code = None
        self._interest_rate = None
        self._loan_amount = None
        self._loan_amount_currency = None
        self._loan_payment_account_type = None
        self._loan_payment_method = None
        self._loan_purpose = None
        self._loan_quota_type = None
        self._loan_term = None
        self._loan_term_unit = None
        self._penalty_rate = None
        self._rate_unit = None
        self._receive_account = None
        self._regular_repay_day = None
        self._repay_day_type = None
        self._repay_mode = None
        self._trade_info = None

    @property
    def actual_controllers(self):
        return self._actual_controllers

    @actual_controllers.setter
    def actual_controllers(self, value):
        if isinstance(value, list):
            self._actual_controllers = list()
            for i in value:
                if isinstance(i, BeneficialEntity):
                    self._actual_controllers.append(i)
                else:
                    self._actual_controllers.append(BeneficialEntity.from_alipay_dict(i))
    @property
    def attachments(self):
        return self._attachments

    @attachments.setter
    def attachments(self, value):
        if isinstance(value, list):
            self._attachments = list()
            for i in value:
                if isinstance(i, FinAttachment):
                    self._attachments.append(i)
                else:
                    self._attachments.append(FinAttachment.from_alipay_dict(i))
    @property
    def beneficiaries(self):
        return self._beneficiaries

    @beneficiaries.setter
    def beneficiaries(self, value):
        if isinstance(value, list):
            self._beneficiaries = list()
            for i in value:
                if isinstance(i, BeneficialEntity):
                    self._beneficiaries.append(i)
                else:
                    self._beneficiaries.append(BeneficialEntity.from_alipay_dict(i))
    @property
    def borrower_type(self):
        return self._borrower_type

    @borrower_type.setter
    def borrower_type(self, value):
        self._borrower_type = value
    @property
    def external_credit_grant_id(self):
        return self._external_credit_grant_id

    @external_credit_grant_id.setter
    def external_credit_grant_id(self, value):
        self._external_credit_grant_id = value
    @property
    def external_loan_id(self):
        return self._external_loan_id

    @external_loan_id.setter
    def external_loan_id(self, value):
        self._external_loan_id = value
    @property
    def external_loan_request_id(self):
        return self._external_loan_request_id

    @external_loan_request_id.setter
    def external_loan_request_id(self, value):
        self._external_loan_request_id = value
    @property
    def external_product_code(self):
        return self._external_product_code

    @external_product_code.setter
    def external_product_code(self, value):
        self._external_product_code = value
    @property
    def external_user_id(self):
        return self._external_user_id

    @external_user_id.setter
    def external_user_id(self, value):
        self._external_user_id = value
    @property
    def inst_code(self):
        return self._inst_code

    @inst_code.setter
    def inst_code(self, value):
        self._inst_code = value
    @property
    def interest_rate(self):
        return self._interest_rate

    @interest_rate.setter
    def interest_rate(self, value):
        self._interest_rate = value
    @property
    def loan_amount(self):
        return self._loan_amount

    @loan_amount.setter
    def loan_amount(self, value):
        self._loan_amount = value
    @property
    def loan_amount_currency(self):
        return self._loan_amount_currency

    @loan_amount_currency.setter
    def loan_amount_currency(self, value):
        self._loan_amount_currency = value
    @property
    def loan_payment_account_type(self):
        return self._loan_payment_account_type

    @loan_payment_account_type.setter
    def loan_payment_account_type(self, value):
        self._loan_payment_account_type = value
    @property
    def loan_payment_method(self):
        return self._loan_payment_method

    @loan_payment_method.setter
    def loan_payment_method(self, value):
        self._loan_payment_method = value
    @property
    def loan_purpose(self):
        return self._loan_purpose

    @loan_purpose.setter
    def loan_purpose(self, value):
        self._loan_purpose = value
    @property
    def loan_quota_type(self):
        return self._loan_quota_type

    @loan_quota_type.setter
    def loan_quota_type(self, value):
        self._loan_quota_type = value
    @property
    def loan_term(self):
        return self._loan_term

    @loan_term.setter
    def loan_term(self, value):
        self._loan_term = value
    @property
    def loan_term_unit(self):
        return self._loan_term_unit

    @loan_term_unit.setter
    def loan_term_unit(self, value):
        self._loan_term_unit = value
    @property
    def penalty_rate(self):
        return self._penalty_rate

    @penalty_rate.setter
    def penalty_rate(self, value):
        self._penalty_rate = value
    @property
    def rate_unit(self):
        return self._rate_unit

    @rate_unit.setter
    def rate_unit(self, value):
        self._rate_unit = value
    @property
    def receive_account(self):
        return self._receive_account

    @receive_account.setter
    def receive_account(self, value):
        if isinstance(value, BankAccount):
            self._receive_account = value
        else:
            self._receive_account = BankAccount.from_alipay_dict(value)
    @property
    def regular_repay_day(self):
        return self._regular_repay_day

    @regular_repay_day.setter
    def regular_repay_day(self, value):
        self._regular_repay_day = value
    @property
    def repay_day_type(self):
        return self._repay_day_type

    @repay_day_type.setter
    def repay_day_type(self, value):
        self._repay_day_type = value
    @property
    def repay_mode(self):
        return self._repay_mode

    @repay_mode.setter
    def repay_mode(self, value):
        self._repay_mode = value
    @property
    def trade_info(self):
        return self._trade_info

    @trade_info.setter
    def trade_info(self, value):
        if isinstance(value, TradeInformation):
            self._trade_info = value
        else:
            self._trade_info = TradeInformation.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.actual_controllers:
            if isinstance(self.actual_controllers, list):
                for i in range(0, len(self.actual_controllers)):
                    element = self.actual_controllers[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.actual_controllers[i] = element.to_alipay_dict()
            if hasattr(self.actual_controllers, 'to_alipay_dict'):
                params['actual_controllers'] = self.actual_controllers.to_alipay_dict()
            else:
                params['actual_controllers'] = self.actual_controllers
        if self.attachments:
            if isinstance(self.attachments, list):
                for i in range(0, len(self.attachments)):
                    element = self.attachments[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.attachments[i] = element.to_alipay_dict()
            if hasattr(self.attachments, 'to_alipay_dict'):
                params['attachments'] = self.attachments.to_alipay_dict()
            else:
                params['attachments'] = self.attachments
        if self.beneficiaries:
            if isinstance(self.beneficiaries, list):
                for i in range(0, len(self.beneficiaries)):
                    element = self.beneficiaries[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.beneficiaries[i] = element.to_alipay_dict()
            if hasattr(self.beneficiaries, 'to_alipay_dict'):
                params['beneficiaries'] = self.beneficiaries.to_alipay_dict()
            else:
                params['beneficiaries'] = self.beneficiaries
        if self.borrower_type:
            if hasattr(self.borrower_type, 'to_alipay_dict'):
                params['borrower_type'] = self.borrower_type.to_alipay_dict()
            else:
                params['borrower_type'] = self.borrower_type
        if self.external_credit_grant_id:
            if hasattr(self.external_credit_grant_id, 'to_alipay_dict'):
                params['external_credit_grant_id'] = self.external_credit_grant_id.to_alipay_dict()
            else:
                params['external_credit_grant_id'] = self.external_credit_grant_id
        if self.external_loan_id:
            if hasattr(self.external_loan_id, 'to_alipay_dict'):
                params['external_loan_id'] = self.external_loan_id.to_alipay_dict()
            else:
                params['external_loan_id'] = self.external_loan_id
        if self.external_loan_request_id:
            if hasattr(self.external_loan_request_id, 'to_alipay_dict'):
                params['external_loan_request_id'] = self.external_loan_request_id.to_alipay_dict()
            else:
                params['external_loan_request_id'] = self.external_loan_request_id
        if self.external_product_code:
            if hasattr(self.external_product_code, 'to_alipay_dict'):
                params['external_product_code'] = self.external_product_code.to_alipay_dict()
            else:
                params['external_product_code'] = self.external_product_code
        if self.external_user_id:
            if hasattr(self.external_user_id, 'to_alipay_dict'):
                params['external_user_id'] = self.external_user_id.to_alipay_dict()
            else:
                params['external_user_id'] = self.external_user_id
        if self.inst_code:
            if hasattr(self.inst_code, 'to_alipay_dict'):
                params['inst_code'] = self.inst_code.to_alipay_dict()
            else:
                params['inst_code'] = self.inst_code
        if self.interest_rate:
            if hasattr(self.interest_rate, 'to_alipay_dict'):
                params['interest_rate'] = self.interest_rate.to_alipay_dict()
            else:
                params['interest_rate'] = self.interest_rate
        if self.loan_amount:
            if hasattr(self.loan_amount, 'to_alipay_dict'):
                params['loan_amount'] = self.loan_amount.to_alipay_dict()
            else:
                params['loan_amount'] = self.loan_amount
        if self.loan_amount_currency:
            if hasattr(self.loan_amount_currency, 'to_alipay_dict'):
                params['loan_amount_currency'] = self.loan_amount_currency.to_alipay_dict()
            else:
                params['loan_amount_currency'] = self.loan_amount_currency
        if self.loan_payment_account_type:
            if hasattr(self.loan_payment_account_type, 'to_alipay_dict'):
                params['loan_payment_account_type'] = self.loan_payment_account_type.to_alipay_dict()
            else:
                params['loan_payment_account_type'] = self.loan_payment_account_type
        if self.loan_payment_method:
            if hasattr(self.loan_payment_method, 'to_alipay_dict'):
                params['loan_payment_method'] = self.loan_payment_method.to_alipay_dict()
            else:
                params['loan_payment_method'] = self.loan_payment_method
        if self.loan_purpose:
            if hasattr(self.loan_purpose, 'to_alipay_dict'):
                params['loan_purpose'] = self.loan_purpose.to_alipay_dict()
            else:
                params['loan_purpose'] = self.loan_purpose
        if self.loan_quota_type:
            if hasattr(self.loan_quota_type, 'to_alipay_dict'):
                params['loan_quota_type'] = self.loan_quota_type.to_alipay_dict()
            else:
                params['loan_quota_type'] = self.loan_quota_type
        if self.loan_term:
            if hasattr(self.loan_term, 'to_alipay_dict'):
                params['loan_term'] = self.loan_term.to_alipay_dict()
            else:
                params['loan_term'] = self.loan_term
        if self.loan_term_unit:
            if hasattr(self.loan_term_unit, 'to_alipay_dict'):
                params['loan_term_unit'] = self.loan_term_unit.to_alipay_dict()
            else:
                params['loan_term_unit'] = self.loan_term_unit
        if self.penalty_rate:
            if hasattr(self.penalty_rate, 'to_alipay_dict'):
                params['penalty_rate'] = self.penalty_rate.to_alipay_dict()
            else:
                params['penalty_rate'] = self.penalty_rate
        if self.rate_unit:
            if hasattr(self.rate_unit, 'to_alipay_dict'):
                params['rate_unit'] = self.rate_unit.to_alipay_dict()
            else:
                params['rate_unit'] = self.rate_unit
        if self.receive_account:
            if hasattr(self.receive_account, 'to_alipay_dict'):
                params['receive_account'] = self.receive_account.to_alipay_dict()
            else:
                params['receive_account'] = self.receive_account
        if self.regular_repay_day:
            if hasattr(self.regular_repay_day, 'to_alipay_dict'):
                params['regular_repay_day'] = self.regular_repay_day.to_alipay_dict()
            else:
                params['regular_repay_day'] = self.regular_repay_day
        if self.repay_day_type:
            if hasattr(self.repay_day_type, 'to_alipay_dict'):
                params['repay_day_type'] = self.repay_day_type.to_alipay_dict()
            else:
                params['repay_day_type'] = self.repay_day_type
        if self.repay_mode:
            if hasattr(self.repay_mode, 'to_alipay_dict'):
                params['repay_mode'] = self.repay_mode.to_alipay_dict()
            else:
                params['repay_mode'] = self.repay_mode
        if self.trade_info:
            if hasattr(self.trade_info, 'to_alipay_dict'):
                params['trade_info'] = self.trade_info.to_alipay_dict()
            else:
                params['trade_info'] = self.trade_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainFinanceTruspleLoanapplySubmitModel()
        if 'actual_controllers' in d:
            o.actual_controllers = d['actual_controllers']
        if 'attachments' in d:
            o.attachments = d['attachments']
        if 'beneficiaries' in d:
            o.beneficiaries = d['beneficiaries']
        if 'borrower_type' in d:
            o.borrower_type = d['borrower_type']
        if 'external_credit_grant_id' in d:
            o.external_credit_grant_id = d['external_credit_grant_id']
        if 'external_loan_id' in d:
            o.external_loan_id = d['external_loan_id']
        if 'external_loan_request_id' in d:
            o.external_loan_request_id = d['external_loan_request_id']
        if 'external_product_code' in d:
            o.external_product_code = d['external_product_code']
        if 'external_user_id' in d:
            o.external_user_id = d['external_user_id']
        if 'inst_code' in d:
            o.inst_code = d['inst_code']
        if 'interest_rate' in d:
            o.interest_rate = d['interest_rate']
        if 'loan_amount' in d:
            o.loan_amount = d['loan_amount']
        if 'loan_amount_currency' in d:
            o.loan_amount_currency = d['loan_amount_currency']
        if 'loan_payment_account_type' in d:
            o.loan_payment_account_type = d['loan_payment_account_type']
        if 'loan_payment_method' in d:
            o.loan_payment_method = d['loan_payment_method']
        if 'loan_purpose' in d:
            o.loan_purpose = d['loan_purpose']
        if 'loan_quota_type' in d:
            o.loan_quota_type = d['loan_quota_type']
        if 'loan_term' in d:
            o.loan_term = d['loan_term']
        if 'loan_term_unit' in d:
            o.loan_term_unit = d['loan_term_unit']
        if 'penalty_rate' in d:
            o.penalty_rate = d['penalty_rate']
        if 'rate_unit' in d:
            o.rate_unit = d['rate_unit']
        if 'receive_account' in d:
            o.receive_account = d['receive_account']
        if 'regular_repay_day' in d:
            o.regular_repay_day = d['regular_repay_day']
        if 'repay_day_type' in d:
            o.repay_day_type = d['repay_day_type']
        if 'repay_mode' in d:
            o.repay_mode = d['repay_mode']
        if 'trade_info' in d:
            o.trade_info = d['trade_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcoCityserviceCityserviceEnergySendResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoCityserviceCityserviceEnergySendResponse, self).__init__()
        self._total_energy = None

    @property
    def total_energy(self):
        return self._total_energy

    @total_energy.setter
    def total_energy(self, value):
        self._total_energy = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoCityserviceCityserviceEnergySendResponse, self).parse_response_content(response_content)
        if 'total_energy' in response:
            self.total_energy = response['total_energy']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundAuthorizeDirectCancelResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundAuthorizeDirectCancelResponse, self).__init__()
        self._agreement_no = None
        self._biz_scene = None
        self._operate_time = None
        self._out_biz_no = None
        self._product_code = None
        self._status = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def operate_time(self):
        return self._operate_time

    @operate_time.setter
    def operate_time(self, value):
        self._operate_time = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundAuthorizeDirectCancelResponse, self).parse_response_content(response_content)
        if 'agreement_no' in response:
            self.agreement_no = response['agreement_no']
        if 'biz_scene' in response:
            self.biz_scene = response['biz_scene']
        if 'operate_time' in response:
            self.operate_time = response['operate_time']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'product_code' in response:
            self.product_code = response['product_code']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.JinyouTestThree import JinyouTestThree


class JinyouTestFour(object):

    def __init__(self):
        self._f_1_openid = None
        self._f_1_y = None
        self._f_2_f = None
        self._f_3_openid = None
        self._f_3_y = None

    @property
    def f_1_openid(self):
        return self._f_1_openid

    @f_1_openid.setter
    def f_1_openid(self, value):
        self._f_1_openid = value
    @property
    def f_1_y(self):
        return self._f_1_y

    @f_1_y.setter
    def f_1_y(self, value):
        self._f_1_y = value
    @property
    def f_2_f(self):
        return self._f_2_f

    @f_2_f.setter
    def f_2_f(self, value):
        if isinstance(value, JinyouTestThree):
            self._f_2_f = value
        else:
            self._f_2_f = JinyouTestThree.from_alipay_dict(value)
    @property
    def f_3_openid(self):
        return self._f_3_openid

    @f_3_openid.setter
    def f_3_openid(self, value):
        self._f_3_openid = value
    @property
    def f_3_y(self):
        return self._f_3_y

    @f_3_y.setter
    def f_3_y(self, value):
        self._f_3_y = value


    def to_alipay_dict(self):
        params = dict()
        if self.f_1_openid:
            if hasattr(self.f_1_openid, 'to_alipay_dict'):
                params['f_1_openid'] = self.f_1_openid.to_alipay_dict()
            else:
                params['f_1_openid'] = self.f_1_openid
        if self.f_1_y:
            if hasattr(self.f_1_y, 'to_alipay_dict'):
                params['f_1_y'] = self.f_1_y.to_alipay_dict()
            else:
                params['f_1_y'] = self.f_1_y
        if self.f_2_f:
            if hasattr(self.f_2_f, 'to_alipay_dict'):
                params['f_2_f'] = self.f_2_f.to_alipay_dict()
            else:
                params['f_2_f'] = self.f_2_f
        if self.f_3_openid:
            if hasattr(self.f_3_openid, 'to_alipay_dict'):
                params['f_3_openid'] = self.f_3_openid.to_alipay_dict()
            else:
                params['f_3_openid'] = self.f_3_openid
        if self.f_3_y:
            if hasattr(self.f_3_y, 'to_alipay_dict'):
                params['f_3_y'] = self.f_3_y.to_alipay_dict()
            else:
                params['f_3_y'] = self.f_3_y
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = JinyouTestFour()
        if 'f_1_openid' in d:
            o.f_1_openid = d['f_1_openid']
        if 'f_1_y' in d:
            o.f_1_y = d['f_1_y']
        if 'f_2_f' in d:
            o.f_2_f = d['f_2_f']
        if 'f_3_openid' in d:
            o.f_3_openid = d['f_3_openid']
        if 'f_3_y' in d:
            o.f_3_y = d['f_3_y']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ChannelPutPlanDetailDTO import ChannelPutPlanDetailDTO


class DatadigitalFincloudFinsaasPutplanQueryResponse(AlipayResponse):

    def __init__(self):
        super(DatadigitalFincloudFinsaasPutplanQueryResponse, self).__init__()
        self._detail = None

    @property
    def detail(self):
        return self._detail

    @detail.setter
    def detail(self, value):
        if isinstance(value, ChannelPutPlanDetailDTO):
            self._detail = value
        else:
            self._detail = ChannelPutPlanDetailDTO.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(DatadigitalFincloudFinsaasPutplanQueryResponse, self).parse_response_content(response_content)
        if 'detail' in response:
            self.detail = response['detail']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOverseasTaxAdvancedPayResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOverseasTaxAdvancedPayResponse, self).__init__()
        self._out_request_no = None
        self._tax_refund_no = None

    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def tax_refund_no(self):
        return self._tax_refund_no

    @tax_refund_no.setter
    def tax_refund_no(self, value):
        self._tax_refund_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayOverseasTaxAdvancedPayResponse, self).parse_response_content(response_content)
        if 'out_request_no' in response:
            self.out_request_no = response['out_request_no']
        if 'tax_refund_no' in response:
            self.tax_refund_no = response['tax_refund_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsSceneClaimNewreportCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsSceneClaimNewreportCreateResponse, self).__init__()
        self._claim_report_no = None

    @property
    def claim_report_no(self):
        return self._claim_report_no

    @claim_report_no.setter
    def claim_report_no(self, value):
        self._claim_report_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsSceneClaimNewreportCreateResponse, self).parse_response_content(response_content)
        if 'claim_report_no' in response:
            self.claim_report_no = response['claim_report_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ExproductconfResponse import ExproductconfResponse


class AlipayEbppProductSearchResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppProductSearchResponse, self).__init__()
        self._exproductconfs = None

    @property
    def exproductconfs(self):
        return self._exproductconfs

    @exproductconfs.setter
    def exproductconfs(self, value):
        if isinstance(value, list):
            self._exproductconfs = list()
            for i in value:
                if isinstance(i, ExproductconfResponse):
                    self._exproductconfs.append(i)
                else:
                    self._exproductconfs.append(ExproductconfResponse.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayEbppProductSearchResponse, self).parse_response_content(response_content)
        if 'exproductconfs' in response:
            self.exproductconfs = response['exproductconfs']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMerchantMrchsurplmorderPointPayModel(object):

    def __init__(self):
        self._biz_id = None
        self._deducted_date = None
        self._item_id = None
        self._lm_order_id = None
        self._merchant_exts = None
        self._point = None
        self._request_id = None
        self._sku_id = None
        self._user_id = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def deducted_date(self):
        return self._deducted_date

    @deducted_date.setter
    def deducted_date(self, value):
        self._deducted_date = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def lm_order_id(self):
        return self._lm_order_id

    @lm_order_id.setter
    def lm_order_id(self, value):
        self._lm_order_id = value
    @property
    def merchant_exts(self):
        return self._merchant_exts

    @merchant_exts.setter
    def merchant_exts(self, value):
        self._merchant_exts = value
    @property
    def point(self):
        return self._point

    @point.setter
    def point(self, value):
        self._point = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def sku_id(self):
        return self._sku_id

    @sku_id.setter
    def sku_id(self, value):
        self._sku_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.deducted_date:
            if hasattr(self.deducted_date, 'to_alipay_dict'):
                params['deducted_date'] = self.deducted_date.to_alipay_dict()
            else:
                params['deducted_date'] = self.deducted_date
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.lm_order_id:
            if hasattr(self.lm_order_id, 'to_alipay_dict'):
                params['lm_order_id'] = self.lm_order_id.to_alipay_dict()
            else:
                params['lm_order_id'] = self.lm_order_id
        if self.merchant_exts:
            if hasattr(self.merchant_exts, 'to_alipay_dict'):
                params['merchant_exts'] = self.merchant_exts.to_alipay_dict()
            else:
                params['merchant_exts'] = self.merchant_exts
        if self.point:
            if hasattr(self.point, 'to_alipay_dict'):
                params['point'] = self.point.to_alipay_dict()
            else:
                params['point'] = self.point
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.sku_id:
            if hasattr(self.sku_id, 'to_alipay_dict'):
                params['sku_id'] = self.sku_id.to_alipay_dict()
            else:
                params['sku_id'] = self.sku_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantMrchsurplmorderPointPayModel()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'deducted_date' in d:
            o.deducted_date = d['deducted_date']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'lm_order_id' in d:
            o.lm_order_id = d['lm_order_id']
        if 'merchant_exts' in d:
            o.merchant_exts = d['merchant_exts']
        if 'point' in d:
            o.point = d['point']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'sku_id' in d:
            o.sku_id = d['sku_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.EcomOrderDTO import EcomOrderDTO


class AlipayInsSceneEcommercePreorderquoteConsultModel(object):

    def __init__(self):
        self._order = None
        self._partner_org_id = None
        self._pre_order_id = None

    @property
    def order(self):
        return self._order

    @order.setter
    def order(self, value):
        if isinstance(value, EcomOrderDTO):
            self._order = value
        else:
            self._order = EcomOrderDTO.from_alipay_dict(value)
    @property
    def partner_org_id(self):
        return self._partner_org_id

    @partner_org_id.setter
    def partner_org_id(self, value):
        self._partner_org_id = value
    @property
    def pre_order_id(self):
        return self._pre_order_id

    @pre_order_id.setter
    def pre_order_id(self, value):
        self._pre_order_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.order:
            if hasattr(self.order, 'to_alipay_dict'):
                params['order'] = self.order.to_alipay_dict()
            else:
                params['order'] = self.order
        if self.partner_org_id:
            if hasattr(self.partner_org_id, 'to_alipay_dict'):
                params['partner_org_id'] = self.partner_org_id.to_alipay_dict()
            else:
                params['partner_org_id'] = self.partner_org_id
        if self.pre_order_id:
            if hasattr(self.pre_order_id, 'to_alipay_dict'):
                params['pre_order_id'] = self.pre_order_id.to_alipay_dict()
            else:
                params['pre_order_id'] = self.pre_order_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneEcommercePreorderquoteConsultModel()
        if 'order' in d:
            o.order = d['order']
        if 'partner_org_id' in d:
            o.partner_org_id = d['partner_org_id']
        if 'pre_order_id' in d:
            o.pre_order_id = d['pre_order_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.StandardVoucherMultipleConditionQueryRequest import StandardVoucherMultipleConditionQueryRequest


class AlipayBossFncGffundStandardvoucherBatchqueryModel(object):

    def __init__(self):
        self._standard_voucher_multiple_condition_query_request = None

    @property
    def standard_voucher_multiple_condition_query_request(self):
        return self._standard_voucher_multiple_condition_query_request

    @standard_voucher_multiple_condition_query_request.setter
    def standard_voucher_multiple_condition_query_request(self, value):
        if isinstance(value, StandardVoucherMultipleConditionQueryRequest):
            self._standard_voucher_multiple_condition_query_request = value
        else:
            self._standard_voucher_multiple_condition_query_request = StandardVoucherMultipleConditionQueryRequest.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.standard_voucher_multiple_condition_query_request:
            if hasattr(self.standard_voucher_multiple_condition_query_request, 'to_alipay_dict'):
                params['standard_voucher_multiple_condition_query_request'] = self.standard_voucher_multiple_condition_query_request.to_alipay_dict()
            else:
                params['standard_voucher_multiple_condition_query_request'] = self.standard_voucher_multiple_condition_query_request
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncGffundStandardvoucherBatchqueryModel()
        if 'standard_voucher_multiple_condition_query_request' in d:
            o.standard_voucher_multiple_condition_query_request = d['standard_voucher_multiple_condition_query_request']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceEducateSceneTokenQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceEducateSceneTokenQueryResponse, self).__init__()
        self._biz_code = None
        self._open_id = None
        self._out_user_id = None
        self._parent_logon_id = None
        self._parent_open_id = None
        self._parent_user_id = None
        self._payment_pid_list = None
        self._school_code = None
        self._school_face_pass_status = None
        self._school_face_payment_status = None
        self._school_std_code = None
        self._user_id = None

    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_user_id(self):
        return self._out_user_id

    @out_user_id.setter
    def out_user_id(self, value):
        self._out_user_id = value
    @property
    def parent_logon_id(self):
        return self._parent_logon_id

    @parent_logon_id.setter
    def parent_logon_id(self, value):
        self._parent_logon_id = value
    @property
    def parent_open_id(self):
        return self._parent_open_id

    @parent_open_id.setter
    def parent_open_id(self, value):
        self._parent_open_id = value
    @property
    def parent_user_id(self):
        return self._parent_user_id

    @parent_user_id.setter
    def parent_user_id(self, value):
        self._parent_user_id = value
    @property
    def payment_pid_list(self):
        return self._payment_pid_list

    @payment_pid_list.setter
    def payment_pid_list(self, value):
        if isinstance(value, list):
            self._payment_pid_list = list()
            for i in value:
                self._payment_pid_list.append(i)
    @property
    def school_code(self):
        return self._school_code

    @school_code.setter
    def school_code(self, value):
        self._school_code = value
    @property
    def school_face_pass_status(self):
        return self._school_face_pass_status

    @school_face_pass_status.setter
    def school_face_pass_status(self, value):
        self._school_face_pass_status = value
    @property
    def school_face_payment_status(self):
        return self._school_face_payment_status

    @school_face_payment_status.setter
    def school_face_payment_status(self, value):
        self._school_face_payment_status = value
    @property
    def school_std_code(self):
        return self._school_std_code

    @school_std_code.setter
    def school_std_code(self, value):
        self._school_std_code = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceEducateSceneTokenQueryResponse, self).parse_response_content(response_content)
        if 'biz_code' in response:
            self.biz_code = response['biz_code']
        if 'open_id' in response:
            self.open_id = response['open_id']
        if 'out_user_id' in response:
            self.out_user_id = response['out_user_id']
        if 'parent_logon_id' in response:
            self.parent_logon_id = response['parent_logon_id']
        if 'parent_open_id' in response:
            self.parent_open_id = response['parent_open_id']
        if 'parent_user_id' in response:
            self.parent_user_id = response['parent_user_id']
        if 'payment_pid_list' in response:
            self.payment_pid_list = response['payment_pid_list']
        if 'school_code' in response:
            self.school_code = response['school_code']
        if 'school_face_pass_status' in response:
            self.school_face_pass_status = response['school_face_pass_status']
        if 'school_face_payment_status' in response:
            self.school_face_payment_status = response['school_face_payment_status']
        if 'school_std_code' in response:
            self.school_std_code = response['school_std_code']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ConsumeInfo(object):

    def __init__(self):
        self._taken_time = None
        self._user_name = None
        self._voucher_amt = None

    @property
    def taken_time(self):
        return self._taken_time

    @taken_time.setter
    def taken_time(self, value):
        self._taken_time = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value
    @property
    def voucher_amt(self):
        return self._voucher_amt

    @voucher_amt.setter
    def voucher_amt(self, value):
        self._voucher_amt = value


    def to_alipay_dict(self):
        params = dict()
        if self.taken_time:
            if hasattr(self.taken_time, 'to_alipay_dict'):
                params['taken_time'] = self.taken_time.to_alipay_dict()
            else:
                params['taken_time'] = self.taken_time
        if self.user_name:
            if hasattr(self.user_name, 'to_alipay_dict'):
                params['user_name'] = self.user_name.to_alipay_dict()
            else:
                params['user_name'] = self.user_name
        if self.voucher_amt:
            if hasattr(self.voucher_amt, 'to_alipay_dict'):
                params['voucher_amt'] = self.voucher_amt.to_alipay_dict()
            else:
                params['voucher_amt'] = self.voucher_amt
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ConsumeInfo()
        if 'taken_time' in d:
            o.taken_time = d['taken_time']
        if 'user_name' in d:
            o.user_name = d['user_name']
        if 'voucher_amt' in d:
            o.voucher_amt = d['voucher_amt']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BPOpenApiAddSignContent import BPOpenApiAddSignContent
from alipay.aop.api.domain.BPOpenApiPUID import BPOpenApiPUID


class AlipayBossBaseProcessInstanceCreateModel(object):

    def __init__(self):
        self._add_sign_content = None
        self._context = None
        self._creator = None
        self._description = None
        self._ip_role_id = None
        self._name = None
        self._priority = None
        self._puid = None
        self._source_node_name = None
        self._source_puid = None
        self._sub_contexts = None

    @property
    def add_sign_content(self):
        return self._add_sign_content

    @add_sign_content.setter
    def add_sign_content(self, value):
        if isinstance(value, list):
            self._add_sign_content = list()
            for i in value:
                if isinstance(i, BPOpenApiAddSignContent):
                    self._add_sign_content.append(i)
                else:
                    self._add_sign_content.append(BPOpenApiAddSignContent.from_alipay_dict(i))
    @property
    def context(self):
        return self._context

    @context.setter
    def context(self, value):
        self._context = value
    @property
    def creator(self):
        return self._creator

    @creator.setter
    def creator(self, value):
        self._creator = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def priority(self):
        return self._priority

    @priority.setter
    def priority(self, value):
        self._priority = value
    @property
    def puid(self):
        return self._puid

    @puid.setter
    def puid(self, value):
        if isinstance(value, BPOpenApiPUID):
            self._puid = value
        else:
            self._puid = BPOpenApiPUID.from_alipay_dict(value)
    @property
    def source_node_name(self):
        return self._source_node_name

    @source_node_name.setter
    def source_node_name(self, value):
        self._source_node_name = value
    @property
    def source_puid(self):
        return self._source_puid

    @source_puid.setter
    def source_puid(self, value):
        self._source_puid = value
    @property
    def sub_contexts(self):
        return self._sub_contexts

    @sub_contexts.setter
    def sub_contexts(self, value):
        if isinstance(value, list):
            self._sub_contexts = list()
            for i in value:
                self._sub_contexts.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.add_sign_content:
            if isinstance(self.add_sign_content, list):
                for i in range(0, len(self.add_sign_content)):
                    element = self.add_sign_content[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.add_sign_content[i] = element.to_alipay_dict()
            if hasattr(self.add_sign_content, 'to_alipay_dict'):
                params['add_sign_content'] = self.add_sign_content.to_alipay_dict()
            else:
                params['add_sign_content'] = self.add_sign_content
        if self.context:
            if hasattr(self.context, 'to_alipay_dict'):
                params['context'] = self.context.to_alipay_dict()
            else:
                params['context'] = self.context
        if self.creator:
            if hasattr(self.creator, 'to_alipay_dict'):
                params['creator'] = self.creator.to_alipay_dict()
            else:
                params['creator'] = self.creator
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.priority:
            if hasattr(self.priority, 'to_alipay_dict'):
                params['priority'] = self.priority.to_alipay_dict()
            else:
                params['priority'] = self.priority
        if self.puid:
            if hasattr(self.puid, 'to_alipay_dict'):
                params['puid'] = self.puid.to_alipay_dict()
            else:
                params['puid'] = self.puid
        if self.source_node_name:
            if hasattr(self.source_node_name, 'to_alipay_dict'):
                params['source_node_name'] = self.source_node_name.to_alipay_dict()
            else:
                params['source_node_name'] = self.source_node_name
        if self.source_puid:
            if hasattr(self.source_puid, 'to_alipay_dict'):
                params['source_puid'] = self.source_puid.to_alipay_dict()
            else:
                params['source_puid'] = self.source_puid
        if self.sub_contexts:
            if isinstance(self.sub_contexts, list):
                for i in range(0, len(self.sub_contexts)):
                    element = self.sub_contexts[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sub_contexts[i] = element.to_alipay_dict()
            if hasattr(self.sub_contexts, 'to_alipay_dict'):
                params['sub_contexts'] = self.sub_contexts.to_alipay_dict()
            else:
                params['sub_contexts'] = self.sub_contexts
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossBaseProcessInstanceCreateModel()
        if 'add_sign_content' in d:
            o.add_sign_content = d['add_sign_content']
        if 'context' in d:
            o.context = d['context']
        if 'creator' in d:
            o.creator = d['creator']
        if 'description' in d:
            o.description = d['description']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'name' in d:
            o.name = d['name']
        if 'priority' in d:
            o.priority = d['priority']
        if 'puid' in d:
            o.puid = d['puid']
        if 'source_node_name' in d:
            o.source_node_name = d['source_node_name']
        if 'source_puid' in d:
            o.source_puid = d['source_puid']
        if 'sub_contexts' in d:
            o.sub_contexts = d['sub_contexts']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BizExtParams(object):

    def __init__(self):
        self._groupon_partners = None

    @property
    def groupon_partners(self):
        return self._groupon_partners

    @groupon_partners.setter
    def groupon_partners(self, value):
        if isinstance(value, list):
            self._groupon_partners = list()
            for i in value:
                self._groupon_partners.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.groupon_partners:
            if isinstance(self.groupon_partners, list):
                for i in range(0, len(self.groupon_partners)):
                    element = self.groupon_partners[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.groupon_partners[i] = element.to_alipay_dict()
            if hasattr(self.groupon_partners, 'to_alipay_dict'):
                params['groupon_partners'] = self.groupon_partners.to_alipay_dict()
            else:
                params['groupon_partners'] = self.groupon_partners
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BizExtParams()
        if 'groupon_partners' in d:
            o.groupon_partners = d['groupon_partners']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiTradeKbdeliveryDeliveryCancelModel(object):

    def __init__(self):
        self._logistics_order_no = None
        self._reason = None

    @property
    def logistics_order_no(self):
        return self._logistics_order_no

    @logistics_order_no.setter
    def logistics_order_no(self, value):
        self._logistics_order_no = value
    @property
    def reason(self):
        return self._reason

    @reason.setter
    def reason(self, value):
        self._reason = value


    def to_alipay_dict(self):
        params = dict()
        if self.logistics_order_no:
            if hasattr(self.logistics_order_no, 'to_alipay_dict'):
                params['logistics_order_no'] = self.logistics_order_no.to_alipay_dict()
            else:
                params['logistics_order_no'] = self.logistics_order_no
        if self.reason:
            if hasattr(self.reason, 'to_alipay_dict'):
                params['reason'] = self.reason.to_alipay_dict()
            else:
                params['reason'] = self.reason
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiTradeKbdeliveryDeliveryCancelModel()
        if 'logistics_order_no' in d:
            o.logistics_order_no = d['logistics_order_no']
        if 'reason' in d:
            o.reason = d['reason']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BillDingBizOrder(object):

    def __init__(self):
        self._amount = None
        self._biz_trans_id = None
        self._biz_type = None
        self._biz_type_desc = None
        self._detail_state_desc = None
        self._detail_title = None
        self._direction = None
        self._gmt_finish = None
        self._id = None
        self._list_title = None
        self._login_id = None
        self._marketing_amount = None
        self._opp_login_id = None
        self._opp_nick_name = None
        self._opp_user_name = None
        self._order_id = None
        self._out_order_no = None
        self._sub_biz_scene = None
        self._title = None
        self._user_name = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def biz_trans_id(self):
        return self._biz_trans_id

    @biz_trans_id.setter
    def biz_trans_id(self, value):
        self._biz_trans_id = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def biz_type_desc(self):
        return self._biz_type_desc

    @biz_type_desc.setter
    def biz_type_desc(self, value):
        self._biz_type_desc = value
    @property
    def detail_state_desc(self):
        return self._detail_state_desc

    @detail_state_desc.setter
    def detail_state_desc(self, value):
        self._detail_state_desc = value
    @property
    def detail_title(self):
        return self._detail_title

    @detail_title.setter
    def detail_title(self, value):
        self._detail_title = value
    @property
    def direction(self):
        return self._direction

    @direction.setter
    def direction(self, value):
        self._direction = value
    @property
    def gmt_finish(self):
        return self._gmt_finish

    @gmt_finish.setter
    def gmt_finish(self, value):
        self._gmt_finish = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def list_title(self):
        return self._list_title

    @list_title.setter
    def list_title(self, value):
        self._list_title = value
    @property
    def login_id(self):
        return self._login_id

    @login_id.setter
    def login_id(self, value):
        self._login_id = value
    @property
    def marketing_amount(self):
        return self._marketing_amount

    @marketing_amount.setter
    def marketing_amount(self, value):
        self._marketing_amount = value
    @property
    def opp_login_id(self):
        return self._opp_login_id

    @opp_login_id.setter
    def opp_login_id(self, value):
        self._opp_login_id = value
    @property
    def opp_nick_name(self):
        return self._opp_nick_name

    @opp_nick_name.setter
    def opp_nick_name(self, value):
        self._opp_nick_name = value
    @property
    def opp_user_name(self):
        return self._opp_user_name

    @opp_user_name.setter
    def opp_user_name(self, value):
        self._opp_user_name = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def sub_biz_scene(self):
        return self._sub_biz_scene

    @sub_biz_scene.setter
    def sub_biz_scene(self, value):
        self._sub_biz_scene = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.biz_trans_id:
            if hasattr(self.biz_trans_id, 'to_alipay_dict'):
                params['biz_trans_id'] = self.biz_trans_id.to_alipay_dict()
            else:
                params['biz_trans_id'] = self.biz_trans_id
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.biz_type_desc:
            if hasattr(self.biz_type_desc, 'to_alipay_dict'):
                params['biz_type_desc'] = self.biz_type_desc.to_alipay_dict()
            else:
                params['biz_type_desc'] = self.biz_type_desc
        if self.detail_state_desc:
            if hasattr(self.detail_state_desc, 'to_alipay_dict'):
                params['detail_state_desc'] = self.detail_state_desc.to_alipay_dict()
            else:
                params['detail_state_desc'] = self.detail_state_desc
        if self.detail_title:
            if hasattr(self.detail_title, 'to_alipay_dict'):
                params['detail_title'] = self.detail_title.to_alipay_dict()
            else:
                params['detail_title'] = self.detail_title
        if self.direction:
            if hasattr(self.direction, 'to_alipay_dict'):
                params['direction'] = self.direction.to_alipay_dict()
            else:
                params['direction'] = self.direction
        if self.gmt_finish:
            if hasattr(self.gmt_finish, 'to_alipay_dict'):
                params['gmt_finish'] = self.gmt_finish.to_alipay_dict()
            else:
                params['gmt_finish'] = self.gmt_finish
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.list_title:
            if hasattr(self.list_title, 'to_alipay_dict'):
                params['list_title'] = self.list_title.to_alipay_dict()
            else:
                params['list_title'] = self.list_title
        if self.login_id:
            if hasattr(self.login_id, 'to_alipay_dict'):
                params['login_id'] = self.login_id.to_alipay_dict()
            else:
                params['login_id'] = self.login_id
        if self.marketing_amount:
            if hasattr(self.marketing_amount, 'to_alipay_dict'):
                params['marketing_amount'] = self.marketing_amount.to_alipay_dict()
            else:
                params['marketing_amount'] = self.marketing_amount
        if self.opp_login_id:
            if hasattr(self.opp_login_id, 'to_alipay_dict'):
                params['opp_login_id'] = self.opp_login_id.to_alipay_dict()
            else:
                params['opp_login_id'] = self.opp_login_id
        if self.opp_nick_name:
            if hasattr(self.opp_nick_name, 'to_alipay_dict'):
                params['opp_nick_name'] = self.opp_nick_name.to_alipay_dict()
            else:
                params['opp_nick_name'] = self.opp_nick_name
        if self.opp_user_name:
            if hasattr(self.opp_user_name, 'to_alipay_dict'):
                params['opp_user_name'] = self.opp_user_name.to_alipay_dict()
            else:
                params['opp_user_name'] = self.opp_user_name
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.sub_biz_scene:
            if hasattr(self.sub_biz_scene, 'to_alipay_dict'):
                params['sub_biz_scene'] = self.sub_biz_scene.to_alipay_dict()
            else:
                params['sub_biz_scene'] = self.sub_biz_scene
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.user_name:
            if hasattr(self.user_name, 'to_alipay_dict'):
                params['user_name'] = self.user_name.to_alipay_dict()
            else:
                params['user_name'] = self.user_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BillDingBizOrder()
        if 'amount' in d:
            o.amount = d['amount']
        if 'biz_trans_id' in d:
            o.biz_trans_id = d['biz_trans_id']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'biz_type_desc' in d:
            o.biz_type_desc = d['biz_type_desc']
        if 'detail_state_desc' in d:
            o.detail_state_desc = d['detail_state_desc']
        if 'detail_title' in d:
            o.detail_title = d['detail_title']
        if 'direction' in d:
            o.direction = d['direction']
        if 'gmt_finish' in d:
            o.gmt_finish = d['gmt_finish']
        if 'id' in d:
            o.id = d['id']
        if 'list_title' in d:
            o.list_title = d['list_title']
        if 'login_id' in d:
            o.login_id = d['login_id']
        if 'marketing_amount' in d:
            o.marketing_amount = d['marketing_amount']
        if 'opp_login_id' in d:
            o.opp_login_id = d['opp_login_id']
        if 'opp_nick_name' in d:
            o.opp_nick_name = d['opp_nick_name']
        if 'opp_user_name' in d:
            o.opp_user_name = d['opp_user_name']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'sub_biz_scene' in d:
            o.sub_biz_scene = d['sub_biz_scene']
        if 'title' in d:
            o.title = d['title']
        if 'user_name' in d:
            o.user_name = d['user_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AvailableTimeInfo import AvailableTimeInfo
from alipay.aop.api.domain.KoubeiItemDescription import KoubeiItemDescription
from alipay.aop.api.domain.UnAvailableTimeInfo import UnAvailableTimeInfo


class KoubeiTradeVoucherItemTemplete(object):

    def __init__(self):
        self._available_time_info_list = None
        self._buyer_notes = None
        self._support_book = None
        self._un_available_time_info_list = None
        self._validity_period = None
        self._validity_period_range_from = None
        self._validity_period_range_to = None
        self._validity_period_type = None
        self._verify_enable_times = None
        self._verify_frequency = None

    @property
    def available_time_info_list(self):
        return self._available_time_info_list

    @available_time_info_list.setter
    def available_time_info_list(self, value):
        if isinstance(value, list):
            self._available_time_info_list = list()
            for i in value:
                if isinstance(i, AvailableTimeInfo):
                    self._available_time_info_list.append(i)
                else:
                    self._available_time_info_list.append(AvailableTimeInfo.from_alipay_dict(i))
    @property
    def buyer_notes(self):
        return self._buyer_notes

    @buyer_notes.setter
    def buyer_notes(self, value):
        if isinstance(value, list):
            self._buyer_notes = list()
            for i in value:
                if isinstance(i, KoubeiItemDescription):
                    self._buyer_notes.append(i)
                else:
                    self._buyer_notes.append(KoubeiItemDescription.from_alipay_dict(i))
    @property
    def support_book(self):
        return self._support_book

    @support_book.setter
    def support_book(self, value):
        self._support_book = value
    @property
    def un_available_time_info_list(self):
        return self._un_available_time_info_list

    @un_available_time_info_list.setter
    def un_available_time_info_list(self, value):
        if isinstance(value, list):
            self._un_available_time_info_list = list()
            for i in value:
                if isinstance(i, UnAvailableTimeInfo):
                    self._un_available_time_info_list.append(i)
                else:
                    self._un_available_time_info_list.append(UnAvailableTimeInfo.from_alipay_dict(i))
    @property
    def validity_period(self):
        return self._validity_period

    @validity_period.setter
    def validity_period(self, value):
        self._validity_period = value
    @property
    def validity_period_range_from(self):
        return self._validity_period_range_from

    @validity_period_range_from.setter
    def validity_period_range_from(self, value):
        self._validity_period_range_from = value
    @property
    def validity_period_range_to(self):
        return self._validity_period_range_to

    @validity_period_range_to.setter
    def validity_period_range_to(self, value):
        self._validity_period_range_to = value
    @property
    def validity_period_type(self):
        return self._validity_period_type

    @validity_period_type.setter
    def validity_period_type(self, value):
        self._validity_period_type = value
    @property
    def verify_enable_times(self):
        return self._verify_enable_times

    @verify_enable_times.setter
    def verify_enable_times(self, value):
        self._verify_enable_times = value
    @property
    def verify_frequency(self):
        return self._verify_frequency

    @verify_frequency.setter
    def verify_frequency(self, value):
        self._verify_frequency = value


    def to_alipay_dict(self):
        params = dict()
        if self.available_time_info_list:
            if isinstance(self.available_time_info_list, list):
                for i in range(0, len(self.available_time_info_list)):
                    element = self.available_time_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.available_time_info_list[i] = element.to_alipay_dict()
            if hasattr(self.available_time_info_list, 'to_alipay_dict'):
                params['available_time_info_list'] = self.available_time_info_list.to_alipay_dict()
            else:
                params['available_time_info_list'] = self.available_time_info_list
        if self.buyer_notes:
            if isinstance(self.buyer_notes, list):
                for i in range(0, len(self.buyer_notes)):
                    element = self.buyer_notes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.buyer_notes[i] = element.to_alipay_dict()
            if hasattr(self.buyer_notes, 'to_alipay_dict'):
                params['buyer_notes'] = self.buyer_notes.to_alipay_dict()
            else:
                params['buyer_notes'] = self.buyer_notes
        if self.support_book:
            if hasattr(self.support_book, 'to_alipay_dict'):
                params['support_book'] = self.support_book.to_alipay_dict()
            else:
                params['support_book'] = self.support_book
        if self.un_available_time_info_list:
            if isinstance(self.un_available_time_info_list, list):
                for i in range(0, len(self.un_available_time_info_list)):
                    element = self.un_available_time_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.un_available_time_info_list[i] = element.to_alipay_dict()
            if hasattr(self.un_available_time_info_list, 'to_alipay_dict'):
                params['un_available_time_info_list'] = self.un_available_time_info_list.to_alipay_dict()
            else:
                params['un_available_time_info_list'] = self.un_available_time_info_list
        if self.validity_period:
            if hasattr(self.validity_period, 'to_alipay_dict'):
                params['validity_period'] = self.validity_period.to_alipay_dict()
            else:
                params['validity_period'] = self.validity_period
        if self.validity_period_range_from:
            if hasattr(self.validity_period_range_from, 'to_alipay_dict'):
                params['validity_period_range_from'] = self.validity_period_range_from.to_alipay_dict()
            else:
                params['validity_period_range_from'] = self.validity_period_range_from
        if self.validity_period_range_to:
            if hasattr(self.validity_period_range_to, 'to_alipay_dict'):
                params['validity_period_range_to'] = self.validity_period_range_to.to_alipay_dict()
            else:
                params['validity_period_range_to'] = self.validity_period_range_to
        if self.validity_period_type:
            if hasattr(self.validity_period_type, 'to_alipay_dict'):
                params['validity_period_type'] = self.validity_period_type.to_alipay_dict()
            else:
                params['validity_period_type'] = self.validity_period_type
        if self.verify_enable_times:
            if hasattr(self.verify_enable_times, 'to_alipay_dict'):
                params['verify_enable_times'] = self.verify_enable_times.to_alipay_dict()
            else:
                params['verify_enable_times'] = self.verify_enable_times
        if self.verify_frequency:
            if hasattr(self.verify_frequency, 'to_alipay_dict'):
                params['verify_frequency'] = self.verify_frequency.to_alipay_dict()
            else:
                params['verify_frequency'] = self.verify_frequency
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiTradeVoucherItemTemplete()
        if 'available_time_info_list' in d:
            o.available_time_info_list = d['available_time_info_list']
        if 'buyer_notes' in d:
            o.buyer_notes = d['buyer_notes']
        if 'support_book' in d:
            o.support_book = d['support_book']
        if 'un_available_time_info_list' in d:
            o.un_available_time_info_list = d['un_available_time_info_list']
        if 'validity_period' in d:
            o.validity_period = d['validity_period']
        if 'validity_period_range_from' in d:
            o.validity_period_range_from = d['validity_period_range_from']
        if 'validity_period_range_to' in d:
            o.validity_period_range_to = d['validity_period_range_to']
        if 'validity_period_type' in d:
            o.validity_period_type = d['validity_period_type']
        if 'verify_enable_times' in d:
            o.verify_enable_times = d['verify_enable_times']
        if 'verify_frequency' in d:
            o.verify_frequency = d['verify_frequency']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ReceiptSku(object):

    def __init__(self):
        self._barcode = None
        self._count = None
        self._name = None
        self._price = None
        self._unit = None

    @property
    def barcode(self):
        return self._barcode

    @barcode.setter
    def barcode(self, value):
        self._barcode = value
    @property
    def count(self):
        return self._count

    @count.setter
    def count(self, value):
        self._count = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def unit(self):
        return self._unit

    @unit.setter
    def unit(self, value):
        self._unit = value


    def to_alipay_dict(self):
        params = dict()
        if self.barcode:
            if hasattr(self.barcode, 'to_alipay_dict'):
                params['barcode'] = self.barcode.to_alipay_dict()
            else:
                params['barcode'] = self.barcode
        if self.count:
            if hasattr(self.count, 'to_alipay_dict'):
                params['count'] = self.count.to_alipay_dict()
            else:
                params['count'] = self.count
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.unit:
            if hasattr(self.unit, 'to_alipay_dict'):
                params['unit'] = self.unit.to_alipay_dict()
            else:
                params['unit'] = self.unit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ReceiptSku()
        if 'barcode' in d:
            o.barcode = d['barcode']
        if 'count' in d:
            o.count = d['count']
        if 'name' in d:
            o.name = d['name']
        if 'price' in d:
            o.price = d['price']
        if 'unit' in d:
            o.unit = d['unit']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundTransThirdpartyRewardCreateModel(object):

    def __init__(self):
        self._amount = None
        self._ext_param = None
        self._out_no = None
        self._receiver_user_id = None
        self._scene = None
        self._sender_user_id = None
        self._title = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def ext_param(self):
        return self._ext_param

    @ext_param.setter
    def ext_param(self, value):
        self._ext_param = value
    @property
    def out_no(self):
        return self._out_no

    @out_no.setter
    def out_no(self, value):
        self._out_no = value
    @property
    def receiver_user_id(self):
        return self._receiver_user_id

    @receiver_user_id.setter
    def receiver_user_id(self, value):
        self._receiver_user_id = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value
    @property
    def sender_user_id(self):
        return self._sender_user_id

    @sender_user_id.setter
    def sender_user_id(self, value):
        self._sender_user_id = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.ext_param:
            if hasattr(self.ext_param, 'to_alipay_dict'):
                params['ext_param'] = self.ext_param.to_alipay_dict()
            else:
                params['ext_param'] = self.ext_param
        if self.out_no:
            if hasattr(self.out_no, 'to_alipay_dict'):
                params['out_no'] = self.out_no.to_alipay_dict()
            else:
                params['out_no'] = self.out_no
        if self.receiver_user_id:
            if hasattr(self.receiver_user_id, 'to_alipay_dict'):
                params['receiver_user_id'] = self.receiver_user_id.to_alipay_dict()
            else:
                params['receiver_user_id'] = self.receiver_user_id
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        if self.sender_user_id:
            if hasattr(self.sender_user_id, 'to_alipay_dict'):
                params['sender_user_id'] = self.sender_user_id.to_alipay_dict()
            else:
                params['sender_user_id'] = self.sender_user_id
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundTransThirdpartyRewardCreateModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'ext_param' in d:
            o.ext_param = d['ext_param']
        if 'out_no' in d:
            o.out_no = d['out_no']
        if 'receiver_user_id' in d:
            o.receiver_user_id = d['receiver_user_id']
        if 'scene' in d:
            o.scene = d['scene']
        if 'sender_user_id' in d:
            o.sender_user_id = d['sender_user_id']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserBenefitStatusUpdateModel(object):

    def __init__(self):
        self._benefit_id = None
        self._benefit_new_flag = None
        self._benefit_status = None

    @property
    def benefit_id(self):
        return self._benefit_id

    @benefit_id.setter
    def benefit_id(self, value):
        self._benefit_id = value
    @property
    def benefit_new_flag(self):
        return self._benefit_new_flag

    @benefit_new_flag.setter
    def benefit_new_flag(self, value):
        self._benefit_new_flag = value
    @property
    def benefit_status(self):
        return self._benefit_status

    @benefit_status.setter
    def benefit_status(self, value):
        self._benefit_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.benefit_id:
            if hasattr(self.benefit_id, 'to_alipay_dict'):
                params['benefit_id'] = self.benefit_id.to_alipay_dict()
            else:
                params['benefit_id'] = self.benefit_id
        if self.benefit_new_flag:
            if hasattr(self.benefit_new_flag, 'to_alipay_dict'):
                params['benefit_new_flag'] = self.benefit_new_flag.to_alipay_dict()
            else:
                params['benefit_new_flag'] = self.benefit_new_flag
        if self.benefit_status:
            if hasattr(self.benefit_status, 'to_alipay_dict'):
                params['benefit_status'] = self.benefit_status.to_alipay_dict()
            else:
                params['benefit_status'] = self.benefit_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserBenefitStatusUpdateModel()
        if 'benefit_id' in d:
            o.benefit_id = d['benefit_id']
        if 'benefit_new_flag' in d:
            o.benefit_new_flag = d['benefit_new_flag']
        if 'benefit_status' in d:
            o.benefit_status = d['benefit_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ShopMerchantInfo(object):

    def __init__(self):
        self._isv_mid = None
        self._name = None
        self._pid = None
        self._sign_mode = None
        self._smid = None

    @property
    def isv_mid(self):
        return self._isv_mid

    @isv_mid.setter
    def isv_mid(self, value):
        self._isv_mid = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def sign_mode(self):
        return self._sign_mode

    @sign_mode.setter
    def sign_mode(self, value):
        self._sign_mode = value
    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value


    def to_alipay_dict(self):
        params = dict()
        if self.isv_mid:
            if hasattr(self.isv_mid, 'to_alipay_dict'):
                params['isv_mid'] = self.isv_mid.to_alipay_dict()
            else:
                params['isv_mid'] = self.isv_mid
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.sign_mode:
            if hasattr(self.sign_mode, 'to_alipay_dict'):
                params['sign_mode'] = self.sign_mode.to_alipay_dict()
            else:
                params['sign_mode'] = self.sign_mode
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ShopMerchantInfo()
        if 'isv_mid' in d:
            o.isv_mid = d['isv_mid']
        if 'name' in d:
            o.name = d['name']
        if 'pid' in d:
            o.pid = d['pid']
        if 'sign_mode' in d:
            o.sign_mode = d['sign_mode']
        if 'smid' in d:
            o.smid = d['smid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
Created on 2017-12-20

@author: liuqun
'''


class AlipayClientConfig(object):

    def __init__(self, sandbox_debug=False):

        # 开发者应用id
        self._app_id = ''
        # 请求签名类型，推荐RSA2
        self._sign_type = 'RSA2'
        # 开发者应用私钥
        self._app_private_key = ''
        # 蚂蚁金服开放平台公钥
        self._alipay_public_key = ''

        # 蚂蚁金服开放平台网关地址
        self._server_url = "https://openapi.alipay.com/gateway.do"
        if sandbox_debug:
            self._server_url = "https://openapi.alipaydev.com/gateway.do"
        # 请求字符集，默认utf-8
        self._charset = 'utf-8'
        # 请求响应报文格式
        self._format = 'json'

        ## 以下为可选参数
        # 请求加密类型（对称加密算法）
        self._encrypt_type = ''
        # 请求加密密钥
        self._encrypt_key = ''
        # 请求读取超时，单位秒，默认15s
        self._timeout = 15

    @property
    def app_id(self):
        return self._app_id

    @app_id.setter
    def app_id(self, value):
        self._app_id = value

    @property
    def sign_type(self):
        return self._sign_type

    @sign_type.setter
    def sign_type(self, value):
        self._sign_type = value

    @property
    def app_private_key(self):
        return self._app_private_key

    @app_private_key.setter
    def app_private_key(self, value):
        self._app_private_key = value

    @property
    def alipay_public_key(self):
        return self._alipay_public_key

    @alipay_public_key.setter
    def alipay_public_key(self, value):
        self._alipay_public_key = value

    @property
    def server_url(self):
        return self._server_url

    @server_url.setter
    def server_url(self, value):
        self._server_url = value

    @property
    def charset(self):
        return self._charset

    @charset.setter
    def charset(self, value):
        self._charset = value

    @property
    def format(self):
        return self._format

    @format.setter
    def format(self, value):
        self._format = value

    @property
    def encrypt_type(self):
        return self._encrypt_type

    @encrypt_type.setter
    def encrypt_type(self, value):
        self._encrypt_type = value

    @property
    def encrypt_key(self):
        return self._encrypt_key

    @encrypt_key.setter
    def encrypt_key(self, value):
        self._encrypt_key = value

    @property
    def timeout(self):
        return self._timeout

    @timeout.setter
    def timeout(self, value):
        self._timeout = value






#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OrderVoucherMerchantAllShopModify(object):

    def __init__(self):
        self._exclude_shop_ids = None

    @property
    def exclude_shop_ids(self):
        return self._exclude_shop_ids

    @exclude_shop_ids.setter
    def exclude_shop_ids(self, value):
        if isinstance(value, list):
            self._exclude_shop_ids = list()
            for i in value:
                self._exclude_shop_ids.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.exclude_shop_ids:
            if isinstance(self.exclude_shop_ids, list):
                for i in range(0, len(self.exclude_shop_ids)):
                    element = self.exclude_shop_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.exclude_shop_ids[i] = element.to_alipay_dict()
            if hasattr(self.exclude_shop_ids, 'to_alipay_dict'):
                params['exclude_shop_ids'] = self.exclude_shop_ids.to_alipay_dict()
            else:
                params['exclude_shop_ids'] = self.exclude_shop_ids
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OrderVoucherMerchantAllShopModify()
        if 'exclude_shop_ids' in d:
            o.exclude_shop_ids = d['exclude_shop_ids']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AvailablePeriodInfo import AvailablePeriodInfo
from alipay.aop.api.domain.BuyerNotesInfo import BuyerNotesInfo
from alipay.aop.api.domain.ItemDishInfo import ItemDishInfo
from alipay.aop.api.domain.ItemPackageInfo import ItemPackageInfo
from alipay.aop.api.domain.IntroductionInfo import IntroductionInfo
from alipay.aop.api.domain.UnavailablePeriodInfo import UnavailablePeriodInfo


class KoubeiCateringItemQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiCateringItemQueryResponse, self).__init__()
        self._available_periods = None
        self._buyer_notes = None
        self._category_id = None
        self._cover = None
        self._external_code_inventory_id = None
        self._external_code_template_id = None
        self._gmt_end = None
        self._gmt_start = None
        self._inventory = None
        self._item_dishes = None
        self._item_display_channel = None
        self._item_id = None
        self._item_packages = None
        self._item_status = None
        self._latest_notice = None
        self._memo = None
        self._merchant_introduction = None
        self._original_price = None
        self._package_notes = None
        self._picture_details = None
        self._price = None
        self._request_id = None
        self._shop_ids = None
        self._sku_id = None
        self._subject = None
        self._taobao_cover_image = None
        self._ticket_display_mode = None
        self._unavailable_periods = None
        self._validity_period = None
        self._weight = None

    @property
    def available_periods(self):
        return self._available_periods

    @available_periods.setter
    def available_periods(self, value):
        if isinstance(value, list):
            self._available_periods = list()
            for i in value:
                if isinstance(i, AvailablePeriodInfo):
                    self._available_periods.append(i)
                else:
                    self._available_periods.append(AvailablePeriodInfo.from_alipay_dict(i))
    @property
    def buyer_notes(self):
        return self._buyer_notes

    @buyer_notes.setter
    def buyer_notes(self, value):
        if isinstance(value, list):
            self._buyer_notes = list()
            for i in value:
                if isinstance(i, BuyerNotesInfo):
                    self._buyer_notes.append(i)
                else:
                    self._buyer_notes.append(BuyerNotesInfo.from_alipay_dict(i))
    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def cover(self):
        return self._cover

    @cover.setter
    def cover(self, value):
        self._cover = value
    @property
    def external_code_inventory_id(self):
        return self._external_code_inventory_id

    @external_code_inventory_id.setter
    def external_code_inventory_id(self, value):
        self._external_code_inventory_id = value
    @property
    def external_code_template_id(self):
        return self._external_code_template_id

    @external_code_template_id.setter
    def external_code_template_id(self, value):
        self._external_code_template_id = value
    @property
    def gmt_end(self):
        return self._gmt_end

    @gmt_end.setter
    def gmt_end(self, value):
        self._gmt_end = value
    @property
    def gmt_start(self):
        return self._gmt_start

    @gmt_start.setter
    def gmt_start(self, value):
        self._gmt_start = value
    @property
    def inventory(self):
        return self._inventory

    @inventory.setter
    def inventory(self, value):
        self._inventory = value
    @property
    def item_dishes(self):
        return self._item_dishes

    @item_dishes.setter
    def item_dishes(self, value):
        if isinstance(value, list):
            self._item_dishes = list()
            for i in value:
                if isinstance(i, ItemDishInfo):
                    self._item_dishes.append(i)
                else:
                    self._item_dishes.append(ItemDishInfo.from_alipay_dict(i))
    @property
    def item_display_channel(self):
        return self._item_display_channel

    @item_display_channel.setter
    def item_display_channel(self, value):
        self._item_display_channel = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def item_packages(self):
        return self._item_packages

    @item_packages.setter
    def item_packages(self, value):
        if isinstance(value, list):
            self._item_packages = list()
            for i in value:
                if isinstance(i, ItemPackageInfo):
                    self._item_packages.append(i)
                else:
                    self._item_packages.append(ItemPackageInfo.from_alipay_dict(i))
    @property
    def item_status(self):
        return self._item_status

    @item_status.setter
    def item_status(self, value):
        self._item_status = value
    @property
    def latest_notice(self):
        return self._latest_notice

    @latest_notice.setter
    def latest_notice(self, value):
        self._latest_notice = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def merchant_introduction(self):
        return self._merchant_introduction

    @merchant_introduction.setter
    def merchant_introduction(self, value):
        if isinstance(value, IntroductionInfo):
            self._merchant_introduction = value
        else:
            self._merchant_introduction = IntroductionInfo.from_alipay_dict(value)
    @property
    def original_price(self):
        return self._original_price

    @original_price.setter
    def original_price(self, value):
        self._original_price = value
    @property
    def package_notes(self):
        return self._package_notes

    @package_notes.setter
    def package_notes(self, value):
        if isinstance(value, list):
            self._package_notes = list()
            for i in value:
                self._package_notes.append(i)
    @property
    def picture_details(self):
        return self._picture_details

    @picture_details.setter
    def picture_details(self, value):
        if isinstance(value, list):
            self._picture_details = list()
            for i in value:
                self._picture_details.append(i)
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def shop_ids(self):
        return self._shop_ids

    @shop_ids.setter
    def shop_ids(self, value):
        if isinstance(value, list):
            self._shop_ids = list()
            for i in value:
                self._shop_ids.append(i)
    @property
    def sku_id(self):
        return self._sku_id

    @sku_id.setter
    def sku_id(self, value):
        self._sku_id = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value
    @property
    def taobao_cover_image(self):
        return self._taobao_cover_image

    @taobao_cover_image.setter
    def taobao_cover_image(self, value):
        self._taobao_cover_image = value
    @property
    def ticket_display_mode(self):
        return self._ticket_display_mode

    @ticket_display_mode.setter
    def ticket_display_mode(self, value):
        self._ticket_display_mode = value
    @property
    def unavailable_periods(self):
        return self._unavailable_periods

    @unavailable_periods.setter
    def unavailable_periods(self, value):
        if isinstance(value, list):
            self._unavailable_periods = list()
            for i in value:
                if isinstance(i, UnavailablePeriodInfo):
                    self._unavailable_periods.append(i)
                else:
                    self._unavailable_periods.append(UnavailablePeriodInfo.from_alipay_dict(i))
    @property
    def validity_period(self):
        return self._validity_period

    @validity_period.setter
    def validity_period(self, value):
        self._validity_period = value
    @property
    def weight(self):
        return self._weight

    @weight.setter
    def weight(self, value):
        self._weight = value

    def parse_response_content(self, response_content):
        response = super(KoubeiCateringItemQueryResponse, self).parse_response_content(response_content)
        if 'available_periods' in response:
            self.available_periods = response['available_periods']
        if 'buyer_notes' in response:
            self.buyer_notes = response['buyer_notes']
        if 'category_id' in response:
            self.category_id = response['category_id']
        if 'cover' in response:
            self.cover = response['cover']
        if 'external_code_inventory_id' in response:
            self.external_code_inventory_id = response['external_code_inventory_id']
        if 'external_code_template_id' in response:
            self.external_code_template_id = response['external_code_template_id']
        if 'gmt_end' in response:
            self.gmt_end = response['gmt_end']
        if 'gmt_start' in response:
            self.gmt_start = response['gmt_start']
        if 'inventory' in response:
            self.inventory = response['inventory']
        if 'item_dishes' in response:
            self.item_dishes = response['item_dishes']
        if 'item_display_channel' in response:
            self.item_display_channel = response['item_display_channel']
        if 'item_id' in response:
            self.item_id = response['item_id']
        if 'item_packages' in response:
            self.item_packages = response['item_packages']
        if 'item_status' in response:
            self.item_status = response['item_status']
        if 'latest_notice' in response:
            self.latest_notice = response['latest_notice']
        if 'memo' in response:
            self.memo = response['memo']
        if 'merchant_introduction' in response:
            self.merchant_introduction = response['merchant_introduction']
        if 'original_price' in response:
            self.original_price = response['original_price']
        if 'package_notes' in response:
            self.package_notes = response['package_notes']
        if 'picture_details' in response:
            self.picture_details = response['picture_details']
        if 'price' in response:
            self.price = response['price']
        if 'request_id' in response:
            self.request_id = response['request_id']
        if 'shop_ids' in response:
            self.shop_ids = response['shop_ids']
        if 'sku_id' in response:
            self.sku_id = response['sku_id']
        if 'subject' in response:
            self.subject = response['subject']
        if 'taobao_cover_image' in response:
            self.taobao_cover_image = response['taobao_cover_image']
        if 'ticket_display_mode' in response:
            self.ticket_display_mode = response['ticket_display_mode']
        if 'unavailable_periods' in response:
            self.unavailable_periods = response['unavailable_periods']
        if 'validity_period' in response:
            self.validity_period = response['validity_period']
        if 'weight' in response:
            self.weight = response['weight']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MultiCurrencyMoneyVO(object):

    def __init__(self):
        self._amt = None
        self._currency_code = None

    @property
    def amt(self):
        return self._amt

    @amt.setter
    def amt(self, value):
        self._amt = value
    @property
    def currency_code(self):
        return self._currency_code

    @currency_code.setter
    def currency_code(self, value):
        self._currency_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.amt:
            if hasattr(self.amt, 'to_alipay_dict'):
                params['amt'] = self.amt.to_alipay_dict()
            else:
                params['amt'] = self.amt
        if self.currency_code:
            if hasattr(self.currency_code, 'to_alipay_dict'):
                params['currency_code'] = self.currency_code.to_alipay_dict()
            else:
                params['currency_code'] = self.currency_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MultiCurrencyMoneyVO()
        if 'amt' in d:
            o.amt = d['amt']
        if 'currency_code' in d:
            o.currency_code = d['currency_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenIotMembershipcouponQueryModel(object):

    def __init__(self):
        self._application_id = None
        self._membership_id = None
        self._service_id = None
        self._sn = None

    @property
    def application_id(self):
        return self._application_id

    @application_id.setter
    def application_id(self, value):
        self._application_id = value
    @property
    def membership_id(self):
        return self._membership_id

    @membership_id.setter
    def membership_id(self, value):
        self._membership_id = value
    @property
    def service_id(self):
        return self._service_id

    @service_id.setter
    def service_id(self, value):
        self._service_id = value
    @property
    def sn(self):
        return self._sn

    @sn.setter
    def sn(self, value):
        self._sn = value


    def to_alipay_dict(self):
        params = dict()
        if self.application_id:
            if hasattr(self.application_id, 'to_alipay_dict'):
                params['application_id'] = self.application_id.to_alipay_dict()
            else:
                params['application_id'] = self.application_id
        if self.membership_id:
            if hasattr(self.membership_id, 'to_alipay_dict'):
                params['membership_id'] = self.membership_id.to_alipay_dict()
            else:
                params['membership_id'] = self.membership_id
        if self.service_id:
            if hasattr(self.service_id, 'to_alipay_dict'):
                params['service_id'] = self.service_id.to_alipay_dict()
            else:
                params['service_id'] = self.service_id
        if self.sn:
            if hasattr(self.sn, 'to_alipay_dict'):
                params['sn'] = self.sn.to_alipay_dict()
            else:
                params['sn'] = self.sn
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenIotMembershipcouponQueryModel()
        if 'application_id' in d:
            o.application_id = d['application_id']
        if 'membership_id' in d:
            o.membership_id = d['membership_id']
        if 'service_id' in d:
            o.service_id = d['service_id']
        if 'sn' in d:
            o.sn = d['sn']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FtokenInfoQuery(object):

    def __init__(self):
        self._account = None
        self._bizid = None
        self._ftoken = None
        self._open_id = None
        self._uid = None

    @property
    def account(self):
        return self._account

    @account.setter
    def account(self, value):
        self._account = value
    @property
    def bizid(self):
        return self._bizid

    @bizid.setter
    def bizid(self, value):
        self._bizid = value
    @property
    def ftoken(self):
        return self._ftoken

    @ftoken.setter
    def ftoken(self, value):
        self._ftoken = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def uid(self):
        return self._uid

    @uid.setter
    def uid(self, value):
        self._uid = value


    def to_alipay_dict(self):
        params = dict()
        if self.account:
            if hasattr(self.account, 'to_alipay_dict'):
                params['account'] = self.account.to_alipay_dict()
            else:
                params['account'] = self.account
        if self.bizid:
            if hasattr(self.bizid, 'to_alipay_dict'):
                params['bizid'] = self.bizid.to_alipay_dict()
            else:
                params['bizid'] = self.bizid
        if self.ftoken:
            if hasattr(self.ftoken, 'to_alipay_dict'):
                params['ftoken'] = self.ftoken.to_alipay_dict()
            else:
                params['ftoken'] = self.ftoken
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.uid:
            if hasattr(self.uid, 'to_alipay_dict'):
                params['uid'] = self.uid.to_alipay_dict()
            else:
                params['uid'] = self.uid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FtokenInfoQuery()
        if 'account' in d:
            o.account = d['account']
        if 'bizid' in d:
            o.bizid = d['bizid']
        if 'ftoken' in d:
            o.ftoken = d['ftoken']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'uid' in d:
            o.uid = d['uid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BakingItemOperationData import BakingItemOperationData


class KoubeiCateringSmartstoreDataSyncModel(object):

    def __init__(self):
        self._baking_item_operation_data = None
        self._browse_dishs = None
        self._browse_time = None
        self._buy_result = None
        self._cabinet_open_time = None
        self._carry_time = None
        self._delivery_end_time = None
        self._delivery_start_time = None
        self._description = None
        self._discount_price = None
        self._item_discount_price = None
        self._item_order_id = None
        self._item_order_name = None
        self._item_price = None
        self._item_quantity = None
        self._order_create_time = None
        self._order_id = None
        self._order_start_time = None
        self._order_type = None
        self._pay_time = None
        self._pay_type = None
        self._people = None
        self._recognize_end_time = None
        self._recognize_start_time = None
        self._recognize_succeed = None
        self._recommend_dishs = None
        self._refund_amount = None
        self._refund_reason = None
        self._refund_time = None
        self._scene = None
        self._shop_id = None
        self._table_number = None
        self._total_price = None
        self._user_id = None

    @property
    def baking_item_operation_data(self):
        return self._baking_item_operation_data

    @baking_item_operation_data.setter
    def baking_item_operation_data(self, value):
        if isinstance(value, BakingItemOperationData):
            self._baking_item_operation_data = value
        else:
            self._baking_item_operation_data = BakingItemOperationData.from_alipay_dict(value)
    @property
    def browse_dishs(self):
        return self._browse_dishs

    @browse_dishs.setter
    def browse_dishs(self, value):
        self._browse_dishs = value
    @property
    def browse_time(self):
        return self._browse_time

    @browse_time.setter
    def browse_time(self, value):
        self._browse_time = value
    @property
    def buy_result(self):
        return self._buy_result

    @buy_result.setter
    def buy_result(self, value):
        self._buy_result = value
    @property
    def cabinet_open_time(self):
        return self._cabinet_open_time

    @cabinet_open_time.setter
    def cabinet_open_time(self, value):
        self._cabinet_open_time = value
    @property
    def carry_time(self):
        return self._carry_time

    @carry_time.setter
    def carry_time(self, value):
        self._carry_time = value
    @property
    def delivery_end_time(self):
        return self._delivery_end_time

    @delivery_end_time.setter
    def delivery_end_time(self, value):
        self._delivery_end_time = value
    @property
    def delivery_start_time(self):
        return self._delivery_start_time

    @delivery_start_time.setter
    def delivery_start_time(self, value):
        self._delivery_start_time = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def discount_price(self):
        return self._discount_price

    @discount_price.setter
    def discount_price(self, value):
        self._discount_price = value
    @property
    def item_discount_price(self):
        return self._item_discount_price

    @item_discount_price.setter
    def item_discount_price(self, value):
        self._item_discount_price = value
    @property
    def item_order_id(self):
        return self._item_order_id

    @item_order_id.setter
    def item_order_id(self, value):
        self._item_order_id = value
    @property
    def item_order_name(self):
        return self._item_order_name

    @item_order_name.setter
    def item_order_name(self, value):
        self._item_order_name = value
    @property
    def item_price(self):
        return self._item_price

    @item_price.setter
    def item_price(self, value):
        self._item_price = value
    @property
    def item_quantity(self):
        return self._item_quantity

    @item_quantity.setter
    def item_quantity(self, value):
        self._item_quantity = value
    @property
    def order_create_time(self):
        return self._order_create_time

    @order_create_time.setter
    def order_create_time(self, value):
        self._order_create_time = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def order_start_time(self):
        return self._order_start_time

    @order_start_time.setter
    def order_start_time(self, value):
        self._order_start_time = value
    @property
    def order_type(self):
        return self._order_type

    @order_type.setter
    def order_type(self, value):
        self._order_type = value
    @property
    def pay_time(self):
        return self._pay_time

    @pay_time.setter
    def pay_time(self, value):
        self._pay_time = value
    @property
    def pay_type(self):
        return self._pay_type

    @pay_type.setter
    def pay_type(self, value):
        self._pay_type = value
    @property
    def people(self):
        return self._people

    @people.setter
    def people(self, value):
        self._people = value
    @property
    def recognize_end_time(self):
        return self._recognize_end_time

    @recognize_end_time.setter
    def recognize_end_time(self, value):
        self._recognize_end_time = value
    @property
    def recognize_start_time(self):
        return self._recognize_start_time

    @recognize_start_time.setter
    def recognize_start_time(self, value):
        self._recognize_start_time = value
    @property
    def recognize_succeed(self):
        return self._recognize_succeed

    @recognize_succeed.setter
    def recognize_succeed(self, value):
        self._recognize_succeed = value
    @property
    def recommend_dishs(self):
        return self._recommend_dishs

    @recommend_dishs.setter
    def recommend_dishs(self, value):
        self._recommend_dishs = value
    @property
    def refund_amount(self):
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, value):
        self._refund_amount = value
    @property
    def refund_reason(self):
        return self._refund_reason

    @refund_reason.setter
    def refund_reason(self, value):
        self._refund_reason = value
    @property
    def refund_time(self):
        return self._refund_time

    @refund_time.setter
    def refund_time(self, value):
        self._refund_time = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def table_number(self):
        return self._table_number

    @table_number.setter
    def table_number(self, value):
        self._table_number = value
    @property
    def total_price(self):
        return self._total_price

    @total_price.setter
    def total_price(self, value):
        self._total_price = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.baking_item_operation_data:
            if hasattr(self.baking_item_operation_data, 'to_alipay_dict'):
                params['baking_item_operation_data'] = self.baking_item_operation_data.to_alipay_dict()
            else:
                params['baking_item_operation_data'] = self.baking_item_operation_data
        if self.browse_dishs:
            if hasattr(self.browse_dishs, 'to_alipay_dict'):
                params['browse_dishs'] = self.browse_dishs.to_alipay_dict()
            else:
                params['browse_dishs'] = self.browse_dishs
        if self.browse_time:
            if hasattr(self.browse_time, 'to_alipay_dict'):
                params['browse_time'] = self.browse_time.to_alipay_dict()
            else:
                params['browse_time'] = self.browse_time
        if self.buy_result:
            if hasattr(self.buy_result, 'to_alipay_dict'):
                params['buy_result'] = self.buy_result.to_alipay_dict()
            else:
                params['buy_result'] = self.buy_result
        if self.cabinet_open_time:
            if hasattr(self.cabinet_open_time, 'to_alipay_dict'):
                params['cabinet_open_time'] = self.cabinet_open_time.to_alipay_dict()
            else:
                params['cabinet_open_time'] = self.cabinet_open_time
        if self.carry_time:
            if hasattr(self.carry_time, 'to_alipay_dict'):
                params['carry_time'] = self.carry_time.to_alipay_dict()
            else:
                params['carry_time'] = self.carry_time
        if self.delivery_end_time:
            if hasattr(self.delivery_end_time, 'to_alipay_dict'):
                params['delivery_end_time'] = self.delivery_end_time.to_alipay_dict()
            else:
                params['delivery_end_time'] = self.delivery_end_time
        if self.delivery_start_time:
            if hasattr(self.delivery_start_time, 'to_alipay_dict'):
                params['delivery_start_time'] = self.delivery_start_time.to_alipay_dict()
            else:
                params['delivery_start_time'] = self.delivery_start_time
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.discount_price:
            if hasattr(self.discount_price, 'to_alipay_dict'):
                params['discount_price'] = self.discount_price.to_alipay_dict()
            else:
                params['discount_price'] = self.discount_price
        if self.item_discount_price:
            if hasattr(self.item_discount_price, 'to_alipay_dict'):
                params['item_discount_price'] = self.item_discount_price.to_alipay_dict()
            else:
                params['item_discount_price'] = self.item_discount_price
        if self.item_order_id:
            if hasattr(self.item_order_id, 'to_alipay_dict'):
                params['item_order_id'] = self.item_order_id.to_alipay_dict()
            else:
                params['item_order_id'] = self.item_order_id
        if self.item_order_name:
            if hasattr(self.item_order_name, 'to_alipay_dict'):
                params['item_order_name'] = self.item_order_name.to_alipay_dict()
            else:
                params['item_order_name'] = self.item_order_name
        if self.item_price:
            if hasattr(self.item_price, 'to_alipay_dict'):
                params['item_price'] = self.item_price.to_alipay_dict()
            else:
                params['item_price'] = self.item_price
        if self.item_quantity:
            if hasattr(self.item_quantity, 'to_alipay_dict'):
                params['item_quantity'] = self.item_quantity.to_alipay_dict()
            else:
                params['item_quantity'] = self.item_quantity
        if self.order_create_time:
            if hasattr(self.order_create_time, 'to_alipay_dict'):
                params['order_create_time'] = self.order_create_time.to_alipay_dict()
            else:
                params['order_create_time'] = self.order_create_time
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.order_start_time:
            if hasattr(self.order_start_time, 'to_alipay_dict'):
                params['order_start_time'] = self.order_start_time.to_alipay_dict()
            else:
                params['order_start_time'] = self.order_start_time
        if self.order_type:
            if hasattr(self.order_type, 'to_alipay_dict'):
                params['order_type'] = self.order_type.to_alipay_dict()
            else:
                params['order_type'] = self.order_type
        if self.pay_time:
            if hasattr(self.pay_time, 'to_alipay_dict'):
                params['pay_time'] = self.pay_time.to_alipay_dict()
            else:
                params['pay_time'] = self.pay_time
        if self.pay_type:
            if hasattr(self.pay_type, 'to_alipay_dict'):
                params['pay_type'] = self.pay_type.to_alipay_dict()
            else:
                params['pay_type'] = self.pay_type
        if self.people:
            if hasattr(self.people, 'to_alipay_dict'):
                params['people'] = self.people.to_alipay_dict()
            else:
                params['people'] = self.people
        if self.recognize_end_time:
            if hasattr(self.recognize_end_time, 'to_alipay_dict'):
                params['recognize_end_time'] = self.recognize_end_time.to_alipay_dict()
            else:
                params['recognize_end_time'] = self.recognize_end_time
        if self.recognize_start_time:
            if hasattr(self.recognize_start_time, 'to_alipay_dict'):
                params['recognize_start_time'] = self.recognize_start_time.to_alipay_dict()
            else:
                params['recognize_start_time'] = self.recognize_start_time
        if self.recognize_succeed:
            if hasattr(self.recognize_succeed, 'to_alipay_dict'):
                params['recognize_succeed'] = self.recognize_succeed.to_alipay_dict()
            else:
                params['recognize_succeed'] = self.recognize_succeed
        if self.recommend_dishs:
            if hasattr(self.recommend_dishs, 'to_alipay_dict'):
                params['recommend_dishs'] = self.recommend_dishs.to_alipay_dict()
            else:
                params['recommend_dishs'] = self.recommend_dishs
        if self.refund_amount:
            if hasattr(self.refund_amount, 'to_alipay_dict'):
                params['refund_amount'] = self.refund_amount.to_alipay_dict()
            else:
                params['refund_amount'] = self.refund_amount
        if self.refund_reason:
            if hasattr(self.refund_reason, 'to_alipay_dict'):
                params['refund_reason'] = self.refund_reason.to_alipay_dict()
            else:
                params['refund_reason'] = self.refund_reason
        if self.refund_time:
            if hasattr(self.refund_time, 'to_alipay_dict'):
                params['refund_time'] = self.refund_time.to_alipay_dict()
            else:
                params['refund_time'] = self.refund_time
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.table_number:
            if hasattr(self.table_number, 'to_alipay_dict'):
                params['table_number'] = self.table_number.to_alipay_dict()
            else:
                params['table_number'] = self.table_number
        if self.total_price:
            if hasattr(self.total_price, 'to_alipay_dict'):
                params['total_price'] = self.total_price.to_alipay_dict()
            else:
                params['total_price'] = self.total_price
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringSmartstoreDataSyncModel()
        if 'baking_item_operation_data' in d:
            o.baking_item_operation_data = d['baking_item_operation_data']
        if 'browse_dishs' in d:
            o.browse_dishs = d['browse_dishs']
        if 'browse_time' in d:
            o.browse_time = d['browse_time']
        if 'buy_result' in d:
            o.buy_result = d['buy_result']
        if 'cabinet_open_time' in d:
            o.cabinet_open_time = d['cabinet_open_time']
        if 'carry_time' in d:
            o.carry_time = d['carry_time']
        if 'delivery_end_time' in d:
            o.delivery_end_time = d['delivery_end_time']
        if 'delivery_start_time' in d:
            o.delivery_start_time = d['delivery_start_time']
        if 'description' in d:
            o.description = d['description']
        if 'discount_price' in d:
            o.discount_price = d['discount_price']
        if 'item_discount_price' in d:
            o.item_discount_price = d['item_discount_price']
        if 'item_order_id' in d:
            o.item_order_id = d['item_order_id']
        if 'item_order_name' in d:
            o.item_order_name = d['item_order_name']
        if 'item_price' in d:
            o.item_price = d['item_price']
        if 'item_quantity' in d:
            o.item_quantity = d['item_quantity']
        if 'order_create_time' in d:
            o.order_create_time = d['order_create_time']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'order_start_time' in d:
            o.order_start_time = d['order_start_time']
        if 'order_type' in d:
            o.order_type = d['order_type']
        if 'pay_time' in d:
            o.pay_time = d['pay_time']
        if 'pay_type' in d:
            o.pay_type = d['pay_type']
        if 'people' in d:
            o.people = d['people']
        if 'recognize_end_time' in d:
            o.recognize_end_time = d['recognize_end_time']
        if 'recognize_start_time' in d:
            o.recognize_start_time = d['recognize_start_time']
        if 'recognize_succeed' in d:
            o.recognize_succeed = d['recognize_succeed']
        if 'recommend_dishs' in d:
            o.recommend_dishs = d['recommend_dishs']
        if 'refund_amount' in d:
            o.refund_amount = d['refund_amount']
        if 'refund_reason' in d:
            o.refund_reason = d['refund_reason']
        if 'refund_time' in d:
            o.refund_time = d['refund_time']
        if 'scene' in d:
            o.scene = d['scene']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'table_number' in d:
            o.table_number = d['table_number']
        if 'total_price' in d:
            o.total_price = d['total_price']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OrderDevice(object):

    def __init__(self):
        self._device_sn = None
        self._install_actual_photo = None
        self._install_mode = None
        self._install_scene_photo = None
        self._is_install_router = None
        self._screen_size = None
        self._supplier_sn = None

    @property
    def device_sn(self):
        return self._device_sn

    @device_sn.setter
    def device_sn(self, value):
        self._device_sn = value
    @property
    def install_actual_photo(self):
        return self._install_actual_photo

    @install_actual_photo.setter
    def install_actual_photo(self, value):
        self._install_actual_photo = value
    @property
    def install_mode(self):
        return self._install_mode

    @install_mode.setter
    def install_mode(self, value):
        self._install_mode = value
    @property
    def install_scene_photo(self):
        return self._install_scene_photo

    @install_scene_photo.setter
    def install_scene_photo(self, value):
        self._install_scene_photo = value
    @property
    def is_install_router(self):
        return self._is_install_router

    @is_install_router.setter
    def is_install_router(self, value):
        self._is_install_router = value
    @property
    def screen_size(self):
        return self._screen_size

    @screen_size.setter
    def screen_size(self, value):
        self._screen_size = value
    @property
    def supplier_sn(self):
        return self._supplier_sn

    @supplier_sn.setter
    def supplier_sn(self, value):
        self._supplier_sn = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_sn:
            if hasattr(self.device_sn, 'to_alipay_dict'):
                params['device_sn'] = self.device_sn.to_alipay_dict()
            else:
                params['device_sn'] = self.device_sn
        if self.install_actual_photo:
            if hasattr(self.install_actual_photo, 'to_alipay_dict'):
                params['install_actual_photo'] = self.install_actual_photo.to_alipay_dict()
            else:
                params['install_actual_photo'] = self.install_actual_photo
        if self.install_mode:
            if hasattr(self.install_mode, 'to_alipay_dict'):
                params['install_mode'] = self.install_mode.to_alipay_dict()
            else:
                params['install_mode'] = self.install_mode
        if self.install_scene_photo:
            if hasattr(self.install_scene_photo, 'to_alipay_dict'):
                params['install_scene_photo'] = self.install_scene_photo.to_alipay_dict()
            else:
                params['install_scene_photo'] = self.install_scene_photo
        if self.is_install_router:
            if hasattr(self.is_install_router, 'to_alipay_dict'):
                params['is_install_router'] = self.is_install_router.to_alipay_dict()
            else:
                params['is_install_router'] = self.is_install_router
        if self.screen_size:
            if hasattr(self.screen_size, 'to_alipay_dict'):
                params['screen_size'] = self.screen_size.to_alipay_dict()
            else:
                params['screen_size'] = self.screen_size
        if self.supplier_sn:
            if hasattr(self.supplier_sn, 'to_alipay_dict'):
                params['supplier_sn'] = self.supplier_sn.to_alipay_dict()
            else:
                params['supplier_sn'] = self.supplier_sn
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OrderDevice()
        if 'device_sn' in d:
            o.device_sn = d['device_sn']
        if 'install_actual_photo' in d:
            o.install_actual_photo = d['install_actual_photo']
        if 'install_mode' in d:
            o.install_mode = d['install_mode']
        if 'install_scene_photo' in d:
            o.install_scene_photo = d['install_scene_photo']
        if 'is_install_router' in d:
            o.is_install_router = d['is_install_router']
        if 'screen_size' in d:
            o.screen_size = d['screen_size']
        if 'supplier_sn' in d:
            o.supplier_sn = d['supplier_sn']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayAssetPointVoucherprodBenefittemplateModifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayAssetPointVoucherprodBenefittemplateModifyResponse, self).__init__()
        self._publish_end_time = None

    @property
    def publish_end_time(self):
        return self._publish_end_time

    @publish_end_time.setter
    def publish_end_time(self, value):
        self._publish_end_time = value

    def parse_response_content(self, response_content):
        response = super(AlipayAssetPointVoucherprodBenefittemplateModifyResponse, self).parse_response_content(response_content)
        if 'publish_end_time' in response:
            self.publish_end_time = response['publish_end_time']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceKidsAccountQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceKidsAccountQueryResponse, self).__init__()
        self._login_name = None
        self._open_id = None
        self._user_id = None

    @property
    def login_name(self):
        return self._login_name

    @login_name.setter
    def login_name(self, value):
        self._login_name = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceKidsAccountQueryResponse, self).parse_response_content(response_content)
        if 'login_name' in response:
            self.login_name = response['login_name']
        if 'open_id' in response:
            self.open_id = response['open_id']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoPrinterStatusQueryModel(object):

    def __init__(self):
        self._client_id = None
        self._client_secret = None
        self._eprint_token = None
        self._machine_code = None

    @property
    def client_id(self):
        return self._client_id

    @client_id.setter
    def client_id(self, value):
        self._client_id = value
    @property
    def client_secret(self):
        return self._client_secret

    @client_secret.setter
    def client_secret(self, value):
        self._client_secret = value
    @property
    def eprint_token(self):
        return self._eprint_token

    @eprint_token.setter
    def eprint_token(self, value):
        self._eprint_token = value
    @property
    def machine_code(self):
        return self._machine_code

    @machine_code.setter
    def machine_code(self, value):
        self._machine_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.client_id:
            if hasattr(self.client_id, 'to_alipay_dict'):
                params['client_id'] = self.client_id.to_alipay_dict()
            else:
                params['client_id'] = self.client_id
        if self.client_secret:
            if hasattr(self.client_secret, 'to_alipay_dict'):
                params['client_secret'] = self.client_secret.to_alipay_dict()
            else:
                params['client_secret'] = self.client_secret
        if self.eprint_token:
            if hasattr(self.eprint_token, 'to_alipay_dict'):
                params['eprint_token'] = self.eprint_token.to_alipay_dict()
            else:
                params['eprint_token'] = self.eprint_token
        if self.machine_code:
            if hasattr(self.machine_code, 'to_alipay_dict'):
                params['machine_code'] = self.machine_code.to_alipay_dict()
            else:
                params['machine_code'] = self.machine_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoPrinterStatusQueryModel()
        if 'client_id' in d:
            o.client_id = d['client_id']
        if 'client_secret' in d:
            o.client_secret = d['client_secret']
        if 'eprint_token' in d:
            o.eprint_token = d['eprint_token']
        if 'machine_code' in d:
            o.machine_code = d['machine_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserLoginCodeGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserLoginCodeGetResponse, self).__init__()
        self._login_code = None

    @property
    def login_code(self):
        return self._login_code

    @login_code.setter
    def login_code(self, value):
        self._login_code = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserLoginCodeGetResponse, self).parse_response_content(response_content)
        if 'login_code' in response:
            self.login_code = response['login_code']
